/* properties.c generated by valac 0.16.0.2-f2187, the Vala compiler
 * generated from properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <gdk/gdk.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block23Data Block23Data;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_PROPERTIES_TYPE_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;
#define _boxes_properties_page_widget_unref0(var) ((var == NULL) ? NULL : (var = (boxes_properties_page_widget_unref (var), NULL)))
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_TYPE_MACHINE_ACTOR (boxes_machine_actor_get_type ())
#define BOXES_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor))
#define BOXES_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))
#define BOXES_IS_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_IS_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_MACHINE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))

typedef struct _BoxesMachineActor BoxesMachineActor;
typedef struct _BoxesMachineActorClass BoxesMachineActorClass;

#define BOXES_TYPE_COLLECTION_SOURCE (boxes_collection_source_get_type ())
#define BOXES_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSource))
#define BOXES_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))
#define BOXES_IS_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_IS_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_COLLECTION_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))

typedef struct _BoxesCollectionSource BoxesCollectionSource;
typedef struct _BoxesCollectionSourceClass BoxesCollectionSourceClass;

#define BOXES_TYPE_DISPLAY_CONFIG (boxes_display_config_get_type ())
#define BOXES_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfig))
#define BOXES_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))
#define BOXES_IS_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_IS_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_DISPLAY_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))

typedef struct _BoxesDisplayConfig BoxesDisplayConfig;
typedef struct _BoxesDisplayConfigClass BoxesDisplayConfigClass;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;

#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesPairPrivate BoxesPairPrivate;
#define _boxes_pair_unref0(var) ((var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL)))
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _BoxesPropertiesParamSpecPageWidget BoxesPropertiesParamSpecPageWidget;

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesProperties {
	BoxesUI parent_instance;
	BoxesPropertiesPrivate * priv;
};

struct _BoxesPropertiesClass {
	BoxesUIClass parent_class;
};

struct _BoxesPropertiesPrivate {
	GtkClutterActor* gtk_actor;
	BoxesApp* app;
	GtkNotebook* notebook;
	GtkToolButton* back;
	GtkLabel* toolbar_label;
	GtkListStore* listmodel;
	GtkTreeView* tree_view;
	GBinding* toolbar_label_bind;
	BoxesMiniGraph* cpu;
	BoxesMiniGraph* io;
	BoxesMiniGraph* net;
	gulong stats_id;
};

struct _Block23Data {
	int _ref_count_;
	BoxesProperties * self;
	BoxesLibvirtMachine* machine;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterState* state;
	ClutterBox* box;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesPropertiesPageWidget {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesPropertiesPageWidgetPrivate * priv;
	GtkWidget* widget;
	gchar* name;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesPropertiesPageWidget *self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
};

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesApp* app;
	BoxesMachineActor* machine_actor;
	BoxesCollectionSource* source;
	BoxesDisplayConfig* config;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	gchar* (*get_screenshot_filename) (BoxesMachine* self, const gchar* ext);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	gchar* (*get_screenshot_prefix) (BoxesMachine* self);
	void (*connect_display) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	GVirDomain* domain;
	GVirConfigDomain* domain_config;
	GVirConnection* connection;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesTopbar {
	BoxesUI parent_instance;
	BoxesTopbarPrivate * priv;
	GtkLabel* label;
	GtkNotebook* notebook;
};

struct _BoxesTopbarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES
} BoxesTopbarPage;

struct _BoxesSidebar {
	BoxesUI parent_instance;
	BoxesSidebarPrivate * priv;
	GtkNotebook* notebook;
	GtkTreeView* default_tree_view;
	GtkTreeView* user_tree_view;
	BoxesCategory* category;
};

struct _BoxesSidebarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_SIDEBAR_PAGE_COLLECTION,
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

struct _BoxesPropertiesPageWidgetPrivate {
	GtkGrid* grid;
};

struct _BoxesPair {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesPairPrivate * priv;
	gpointer first;
	gpointer second;
};

struct _BoxesPairClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesPair *self);
};

struct _BoxesPropertiesParamSpecPageWidget {
	GParamSpec parent_instance;
};


static gpointer boxes_properties_parent_class = NULL;
static gpointer boxes_properties_page_widget_parent_class = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES, BoxesPropertiesPrivate))
enum  {
	BOXES_PROPERTIES_DUMMY_PROPERTY,
	BOXES_PROPERTIES_ACTOR
};
BoxesProperties* boxes_properties_new (BoxesApp* app);
BoxesProperties* boxes_properties_construct (GType object_type, BoxesApp* app);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_properties_setup_ui (BoxesProperties* self);
static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label);
static void boxes_properties_populate (BoxesProperties* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static Block23Data* block23_data_ref (Block23Data* _data23_);
static void block23_data_unref (void * _userdata_);
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
static gpointer boxes_properties_page_widget_ref (gpointer instance);
static void boxes_properties_page_widget_unref (gpointer instance);
static GParamSpec* boxes_properties_param_spec_page_widget (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void boxes_properties_value_set_page_widget (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void boxes_properties_value_take_page_widget (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer boxes_properties_value_get_page_widget (const GValue* value) G_GNUC_UNUSED;
static GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void ___lambda101_ (Block23Data* _data23_);
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_actor_get_type (void) G_GNUC_CONST;
GType boxes_collection_source_get_type (void) G_GNUC_CONST;
GType boxes_display_config_get_type (void) G_GNUC_CONST;
void boxes_mini_graph_set_points (BoxesMiniGraph* self, gdouble* value, int value_length1);
static void ____lambda101__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self);
GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
#define BOXES_TOPBAR_height ((guint) 50)
static void __lambda99_ (BoxesProperties* self, GtkToolButton* button);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda99__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
GType boxes_category_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate);
static void __lambda100_ (BoxesProperties* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column);
static void ___lambda100__gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self);
BoxesMiniGraph* boxes_mini_graph_new_with_ymax (gdouble* points, int points_length1, gdouble ymax, gint npoints);
BoxesMiniGraph* boxes_mini_graph_construct_with_ymax (GType object_type, gdouble* points, int points_length1, gdouble ymax, gint npoints);
BoxesMiniGraph* boxes_mini_graph_new (gdouble* points, int points_length1, gint npoints);
BoxesMiniGraph* boxes_mini_graph_construct (GType object_type, gdouble* points, int points_length1, gint npoints);
static void boxes_properties_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetPrivate))
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_DUMMY_PROPERTY
};
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page);
void boxes_get_color (const gchar* desc, GdkColor* result);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
static void boxes_properties_page_widget_finalize (BoxesPropertiesPageWidget* obj);
static void boxes_properties_finalize (GObject* obj);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


GType boxes_properties_page_get_type (void) {
	static volatile gsize boxes_properties_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_PROPERTIES_PAGE_LOGIN, "BOXES_PROPERTIES_PAGE_LOGIN", "login"}, {BOXES_PROPERTIES_PAGE_SYSTEM, "BOXES_PROPERTIES_PAGE_SYSTEM", "system"}, {BOXES_PROPERTIES_PAGE_DISPLAY, "BOXES_PROPERTIES_PAGE_DISPLAY", "display"}, {BOXES_PROPERTIES_PAGE_DEVICES, "BOXES_PROPERTIES_PAGE_DEVICES", "devices"}, {BOXES_PROPERTIES_PAGE_LAST, "BOXES_PROPERTIES_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_properties_page_type_id;
		boxes_properties_page_type_id = g_enum_register_static ("BoxesPropertiesPage", values);
		g_once_init_leave (&boxes_properties_page_type_id__volatile, boxes_properties_page_type_id);
	}
	return boxes_properties_page_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


BoxesProperties* boxes_properties_construct (GType object_type, BoxesApp* app) {
	BoxesProperties * self = NULL;
	BoxesApp* _tmp0_;
	BoxesApp* _tmp1_;
	g_return_val_if_fail (app != NULL, NULL);
	self = (BoxesProperties*) boxes_ui_construct (object_type);
	_tmp0_ = app;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->priv->app);
	self->priv->app = _tmp1_;
	boxes_properties_setup_ui (self);
	return self;
}


BoxesProperties* boxes_properties_new (BoxesApp* app) {
	return boxes_properties_construct (BOXES_TYPE_PROPERTIES, app);
}


static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_;
	GtkTreeIter _tmp3_;
	const gchar* _tmp4_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (listmodel != NULL);
	g_return_if_fail (label != NULL);
	_tmp0_ = listmodel;
	gtk_list_store_append (_tmp0_, &_tmp1_);
	iter = _tmp1_;
	_tmp2_ = listmodel;
	_tmp3_ = iter;
	_tmp4_ = label;
	gtk_list_store_set (_tmp2_, &_tmp3_, 0, _tmp4_, -1);
}


static Block23Data* block23_data_ref (Block23Data* _data23_) {
	g_atomic_int_inc (&_data23_->_ref_count_);
	return _data23_;
}


static void block23_data_unref (void * _userdata_) {
	Block23Data* _data23_;
	_data23_ = (Block23Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data23_->_ref_count_)) {
		BoxesProperties * self;
		self = _data23_->self;
		_g_object_unref0 (_data23_->machine);
		_g_object_unref0 (self);
		g_slice_free (Block23Data, _data23_);
	}
}


static void ___lambda101_ (Block23Data* _data23_) {
	BoxesProperties * self;
	BoxesMiniGraph* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	gdouble* _tmp2_;
	gint _tmp2__length1;
	BoxesMiniGraph* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
	gdouble* _tmp5_;
	gint _tmp5__length1;
	BoxesMiniGraph* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	gdouble* _tmp8_;
	gint _tmp8__length1;
	self = _data23_->self;
	_tmp0_ = self->priv->cpu;
	_tmp1_ = _data23_->machine;
	_tmp2_ = _tmp1_->cpu_stats;
	_tmp2__length1 = _tmp1_->cpu_stats_length1;
	boxes_mini_graph_set_points (_tmp0_, _tmp2_, _tmp2__length1);
	_tmp3_ = self->priv->net;
	_tmp4_ = _data23_->machine;
	_tmp5_ = _tmp4_->net_stats;
	_tmp5__length1 = _tmp4_->net_stats_length1;
	boxes_mini_graph_set_points (_tmp3_, _tmp5_, _tmp5__length1);
	_tmp6_ = self->priv->io;
	_tmp7_ = _data23_->machine;
	_tmp8_ = _tmp7_->io_stats;
	_tmp8__length1 = _tmp7_->io_stats_length1;
	boxes_mini_graph_set_points (_tmp6_, _tmp8_, _tmp8__length1);
}


static void ____lambda101__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self) {
	___lambda101_ (self);
}


static void boxes_properties_populate (BoxesProperties* self) {
	Block23Data* _data23_;
	GtkListStore* _tmp0_;
	BoxesApp* _tmp6_;
	BoxesCollectionItem* _tmp7_;
	GtkTreeView* _tmp26_;
	GtkTreeSelection* _tmp27_ = NULL;
	GtkTreePath* _tmp28_;
	GtkTreePath* _tmp29_;
	BoxesApp* _tmp30_;
	BoxesCollectionItem* _tmp31_;
	BoxesLibvirtMachine* _tmp32_;
	BoxesLibvirtMachine* _tmp33_;
	g_return_if_fail (self != NULL);
	_data23_ = g_slice_new0 (Block23Data);
	_data23_->_ref_count_ = 1;
	_data23_->self = g_object_ref (self);
	_tmp0_ = self->priv->listmodel;
	gtk_list_store_clear (_tmp0_);
	{
		gint i;
		i = 0;
		{
			gboolean _tmp1_;
			_tmp1_ = TRUE;
			while (TRUE) {
				gboolean _tmp2_;
				gint _tmp4_;
				GtkNotebook* _tmp5_;
				_tmp2_ = _tmp1_;
				if (!_tmp2_) {
					gint _tmp3_;
					_tmp3_ = i;
					i = _tmp3_ + 1;
				}
				_tmp1_ = FALSE;
				_tmp4_ = i;
				if (!(_tmp4_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
					break;
				}
				_tmp5_ = self->priv->notebook;
				gtk_notebook_remove_page (_tmp5_, -1);
			}
		}
	}
	_tmp6_ = self->priv->app;
	_tmp7_ = _tmp6_->current_item;
	if (_tmp7_ == NULL) {
		block23_data_unref (_data23_);
		_data23_ = NULL;
		return;
	}
	{
		gint i;
		i = 0;
		{
			gboolean _tmp8_;
			_tmp8_ = TRUE;
			while (TRUE) {
				gboolean _tmp9_;
				gint _tmp11_;
				BoxesApp* _tmp12_;
				BoxesCollectionItem* _tmp13_;
				BoxesMachine* _tmp14_;
				BoxesMachine* machine;
				gint _tmp15_;
				BoxesMachine* _tmp16_;
				BoxesPropertiesPageWidget* _tmp17_;
				BoxesPropertiesPageWidget* page;
				GtkNotebook* _tmp18_;
				BoxesPropertiesPageWidget* _tmp19_;
				GtkWidget* _tmp20_;
				BoxesPropertiesPageWidget* _tmp21_;
				gboolean _tmp22_;
				_tmp9_ = _tmp8_;
				if (!_tmp9_) {
					gint _tmp10_;
					_tmp10_ = i;
					i = _tmp10_ + 1;
				}
				_tmp8_ = FALSE;
				_tmp11_ = i;
				if (!(_tmp11_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
					break;
				}
				_tmp12_ = self->priv->app;
				_tmp13_ = _tmp12_->current_item;
				_tmp14_ = _g_object_ref0 (BOXES_IS_MACHINE (_tmp13_) ? ((BoxesMachine*) _tmp13_) : NULL);
				machine = _tmp14_;
				_tmp15_ = i;
				_tmp16_ = machine;
				_tmp17_ = boxes_properties_page_widget_new (_tmp15_, _tmp16_);
				page = _tmp17_;
				_tmp18_ = self->priv->notebook;
				_tmp19_ = page;
				_tmp20_ = _tmp19_->widget;
				gtk_notebook_append_page (_tmp18_, _tmp20_, NULL);
				_tmp21_ = page;
				_tmp22_ = _tmp21_->empty;
				if (!_tmp22_) {
					GtkListStore* _tmp23_;
					BoxesPropertiesPageWidget* _tmp24_;
					const gchar* _tmp25_;
					_tmp23_ = self->priv->listmodel;
					_tmp24_ = page;
					_tmp25_ = _tmp24_->name;
					boxes_properties_list_append (self, _tmp23_, _tmp25_);
				}
				_boxes_properties_page_widget_unref0 (page);
				_g_object_unref0 (machine);
			}
		}
	}
	_tmp26_ = self->priv->tree_view;
	_tmp27_ = gtk_tree_view_get_selection (_tmp26_);
	_tmp28_ = gtk_tree_path_new_from_string ("0");
	_tmp29_ = _tmp28_;
	gtk_tree_selection_select_path (_tmp27_, _tmp29_);
	_gtk_tree_path_free0 (_tmp29_);
	_tmp30_ = self->priv->app;
	_tmp31_ = _tmp30_->current_item;
	_tmp32_ = _g_object_ref0 (BOXES_IS_LIBVIRT_MACHINE (_tmp31_) ? ((BoxesLibvirtMachine*) _tmp31_) : NULL);
	_data23_->machine = _tmp32_;
	_tmp33_ = _data23_->machine;
	if (_tmp33_ != NULL) {
		BoxesLibvirtMachine* _tmp34_;
		gulong _tmp35_ = 0UL;
		_tmp34_ = _data23_->machine;
		_tmp35_ = g_signal_connect_data (_tmp34_, "stats-updated", (GCallback) ____lambda101__boxes_libvirt_machine_stats_updated, block23_data_ref (_data23_), (GClosureNotify) block23_data_unref, 0);
		self->priv->stats_id = _tmp35_;
	}
	block23_data_unref (_data23_);
	_data23_ = NULL;
}


static void __lambda99_ (BoxesProperties* self, GtkToolButton* button) {
	BoxesApp* _tmp0_;
	g_return_if_fail (button != NULL);
	_tmp0_ = self->priv->app;
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_DISPLAY);
}


static void ___lambda99__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
	__lambda99_ (self, _sender);
}


static void __lambda100_ (BoxesProperties* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column) {
	GtkNotebook* _tmp0_;
	GtkTreePath* _tmp1_;
	gint _tmp2_ = 0;
	gint* _tmp3_ = NULL;
	gint _tmp4_;
	g_return_if_fail (treeview != NULL);
	g_return_if_fail (path != NULL);
	g_return_if_fail (column != NULL);
	_tmp0_ = self->priv->notebook;
	_tmp1_ = path;
	_tmp3_ = gtk_tree_path_get_indices_with_depth (_tmp1_, &_tmp2_);
	_tmp4_ = _tmp3_[0];
	g_object_set (_tmp0_, "page", _tmp4_, NULL);
}


static void ___lambda100__gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self) {
	__lambda100_ (self, _sender, path, column);
}


static void boxes_properties_setup_ui (BoxesProperties* self) {
	GtkNotebook* _tmp0_;
	GtkNotebook* _tmp1_;
	GtkNotebook* _tmp2_;
	GtkNotebook* _tmp3_;
	GtkStyleContext* _tmp4_ = NULL;
	GtkNotebook* _tmp5_;
	GtkClutterActor* _tmp6_;
	GtkClutterActor* _tmp7_;
	BoxesApp* _tmp8_;
	BoxesTopbar* _tmp9_;
	GtkNotebook* _tmp10_;
	GtkWidget* _tmp11_ = NULL;
	GtkHBox* _tmp12_;
	GtkHBox* hbox;
	GtkToolbar* _tmp13_;
	GtkToolbar* _tmp14_;
	GtkToolbar* toolbar;
	GtkStyleContext* _tmp15_ = NULL;
	GtkHBox* _tmp16_;
	GtkHBox* _tmp17_;
	GtkHBox* toolbar_box;
	GtkHBox* _tmp18_;
	GtkHBox* _tmp19_;
	GtkHBox* box;
	GtkImage* _tmp20_;
	GtkImage* _tmp21_;
	GtkLabel* _tmp22_;
	GtkLabel* _tmp23_;
	GtkLabel* _tmp24_;
	GtkToolButton* _tmp25_;
	GtkToolButton* _tmp26_;
	GtkToolButton* _tmp27_;
	GtkStyleContext* _tmp28_ = NULL;
	GtkToolButton* _tmp29_;
	GtkToolButton* _tmp30_;
	BoxesApp* _tmp31_;
	BoxesSidebar* _tmp32_;
	GtkNotebook* _tmp33_;
	GtkWidget* _tmp34_ = NULL;
	GtkVBox* _tmp35_;
	GtkVBox* vbox;
	GtkTreeView* _tmp36_;
	GtkTreeView* _tmp37_;
	GtkTreeView* _tmp38_;
	GtkTreeSelection* _tmp39_ = NULL;
	GtkTreeSelection* _tmp40_;
	GtkTreeSelection* selection;
	GtkTreeView* _tmp41_;
	GtkTreeView* _tmp42_;
	GtkListStore* _tmp43_;
	GtkTreeView* _tmp44_;
	GtkListStore* _tmp45_;
	GtkTreeView* _tmp46_;
	GtkCellRendererText* _tmp47_;
	GtkCellRendererText* _tmp48_;
	GtkCellRendererText* renderer;
	GtkTreeView* _tmp49_;
	GtkTreeView* _tmp50_;
	GtkGrid* _tmp51_;
	GtkGrid* _tmp52_;
	GtkGrid* grid;
	const gchar* _tmp53_ = NULL;
	GtkLabel* _tmp54_;
	GtkLabel* _tmp55_;
	GtkLabel* label;
	GtkLabel* _tmp56_;
	GtkStyleContext* _tmp57_ = NULL;
	GtkLabel* _tmp58_;
	gdouble* _tmp59_ = NULL;
	gdouble* _tmp60_;
	gint _tmp60__length1;
	BoxesMiniGraph* _tmp61_;
	BoxesMiniGraph* _tmp62_;
	BoxesMiniGraph* _tmp63_;
	BoxesMiniGraph* _tmp64_;
	const gchar* _tmp65_ = NULL;
	GtkLabel* _tmp66_;
	GtkLabel* _tmp67_;
	GtkLabel* _tmp68_;
	GtkStyleContext* _tmp69_ = NULL;
	GtkLabel* _tmp70_;
	gdouble* _tmp71_ = NULL;
	gdouble* _tmp72_;
	gint _tmp72__length1;
	BoxesMiniGraph* _tmp73_;
	BoxesMiniGraph* _tmp74_;
	BoxesMiniGraph* _tmp75_;
	BoxesMiniGraph* _tmp76_;
	const gchar* _tmp77_ = NULL;
	GtkLabel* _tmp78_;
	GtkLabel* _tmp79_;
	GtkLabel* _tmp80_;
	GtkStyleContext* _tmp81_ = NULL;
	GtkLabel* _tmp82_;
	gdouble* _tmp83_ = NULL;
	gdouble* _tmp84_;
	gint _tmp84__length1;
	BoxesMiniGraph* _tmp85_;
	BoxesMiniGraph* _tmp86_;
	BoxesMiniGraph* _tmp87_;
	BoxesMiniGraph* _tmp88_;
	GtkNotebook* _tmp89_;
	g_return_if_fail (self != NULL);
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
	_tmp1_ = g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->notebook);
	self->priv->notebook = _tmp1_;
	_tmp2_ = self->priv->notebook;
	gtk_notebook_set_show_tabs (_tmp2_, FALSE);
	_tmp3_ = self->priv->notebook;
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
	gtk_style_context_add_class (_tmp4_, "boxes-bg");
	_tmp5_ = self->priv->notebook;
	_tmp6_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp5_);
	_tmp7_ = g_object_ref_sink (_tmp6_);
	_g_object_unref0 (self->priv->gtk_actor);
	self->priv->gtk_actor = _tmp7_;
	_tmp8_ = self->priv->app;
	_tmp9_ = _tmp8_->topbar;
	_tmp10_ = _tmp9_->notebook;
	_tmp11_ = gtk_notebook_get_nth_page (_tmp10_, (gint) BOXES_TOPBAR_PAGE_PROPERTIES);
	_tmp12_ = _g_object_ref0 (GTK_IS_HBOX (_tmp11_) ? ((GtkHBox*) _tmp11_) : NULL);
	hbox = _tmp12_;
	_tmp13_ = (GtkToolbar*) gtk_toolbar_new ();
	_tmp14_ = g_object_ref_sink (_tmp13_);
	toolbar = _tmp14_;
	gtk_widget_set_valign ((GtkWidget*) toolbar, GTK_ALIGN_CENTER);
	gtk_toolbar_set_icon_size (toolbar, (gint) GTK_ICON_SIZE_MENU);
	_tmp15_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
	gtk_style_context_add_class (_tmp15_, GTK_STYLE_CLASS_MENUBAR);
	gtk_toolbar_set_show_arrow (toolbar, FALSE);
	_tmp16_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
	_tmp17_ = g_object_ref_sink (_tmp16_);
	toolbar_box = _tmp17_;
	gtk_widget_set_size_request ((GtkWidget*) toolbar_box, 50, (gint) BOXES_TOPBAR_height);
	gtk_container_add ((GtkContainer*) toolbar_box, (GtkWidget*) toolbar);
	_tmp18_ = (GtkHBox*) gtk_hbox_new (FALSE, 5);
	_tmp19_ = g_object_ref_sink (_tmp18_);
	box = _tmp19_;
	_tmp20_ = (GtkImage*) gtk_image_new_from_icon_name ("go-previous-symbolic", GTK_ICON_SIZE_MENU);
	_tmp21_ = g_object_ref_sink (_tmp20_);
	gtk_container_add ((GtkContainer*) box, (GtkWidget*) _tmp21_);
	_g_object_unref0 (_tmp21_);
	_tmp22_ = (GtkLabel*) gtk_label_new ("label");
	_tmp23_ = g_object_ref_sink (_tmp22_);
	_g_object_unref0 (self->priv->toolbar_label);
	self->priv->toolbar_label = _tmp23_;
	_tmp24_ = self->priv->toolbar_label;
	gtk_container_add ((GtkContainer*) box, (GtkWidget*) _tmp24_);
	_tmp25_ = (GtkToolButton*) gtk_tool_button_new ((GtkWidget*) box, NULL);
	_tmp26_ = g_object_ref_sink (_tmp25_);
	_g_object_unref0 (self->priv->back);
	self->priv->back = _tmp26_;
	_tmp27_ = self->priv->back;
	_tmp28_ = gtk_widget_get_style_context ((GtkWidget*) _tmp27_);
	gtk_style_context_add_class (_tmp28_, "raised");
	_tmp29_ = self->priv->back;
	g_signal_connect_object (_tmp29_, "clicked", (GCallback) ___lambda99__gtk_tool_button_clicked, self, 0);
	_tmp30_ = self->priv->back;
	gtk_toolbar_insert (toolbar, (GtkToolItem*) _tmp30_, 0);
	gtk_box_pack_start ((GtkBox*) hbox, (GtkWidget*) toolbar_box, TRUE, TRUE, (guint) 0);
	gtk_widget_show_all ((GtkWidget*) hbox);
	_tmp31_ = self->priv->app;
	_tmp32_ = _tmp31_->sidebar;
	_tmp33_ = _tmp32_->notebook;
	_tmp34_ = gtk_notebook_get_nth_page (_tmp33_, (gint) BOXES_SIDEBAR_PAGE_PROPERTIES);
	_tmp35_ = _g_object_ref0 (GTK_IS_VBOX (_tmp34_) ? ((GtkVBox*) _tmp34_) : NULL);
	vbox = _tmp35_;
	_tmp36_ = (GtkTreeView*) gtk_tree_view_new ();
	_tmp37_ = g_object_ref_sink (_tmp36_);
	_g_object_unref0 (self->priv->tree_view);
	self->priv->tree_view = _tmp37_;
	_tmp38_ = self->priv->tree_view;
	_tmp39_ = gtk_tree_view_get_selection (_tmp38_);
	_tmp40_ = _g_object_ref0 (_tmp39_);
	selection = _tmp40_;
	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
	_tmp41_ = self->priv->tree_view;
	boxes_tree_view_activate_on_single_click (_tmp41_, TRUE);
	_tmp42_ = self->priv->tree_view;
	g_signal_connect_object (_tmp42_, "row-activated", (GCallback) ___lambda100__gtk_tree_view_row_activated, self, 0);
	_tmp43_ = gtk_list_store_new (1, G_TYPE_STRING);
	_g_object_unref0 (self->priv->listmodel);
	self->priv->listmodel = _tmp43_;
	_tmp44_ = self->priv->tree_view;
	_tmp45_ = self->priv->listmodel;
	gtk_tree_view_set_model (_tmp44_, (GtkTreeModel*) _tmp45_);
	_tmp46_ = self->priv->tree_view;
	gtk_tree_view_set_headers_visible (_tmp46_, FALSE);
	_tmp47_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
	_tmp48_ = g_object_ref_sink (_tmp47_);
	renderer = _tmp48_;
	g_object_set ((GtkCellRenderer*) renderer, "xpad", (guint) 20, NULL);
	_tmp49_ = self->priv->tree_view;
	gtk_tree_view_insert_column_with_attributes (_tmp49_, -1, "", (GtkCellRenderer*) renderer, "text", 0, NULL);
	_tmp50_ = self->priv->tree_view;
	gtk_box_pack_start ((GtkBox*) vbox, (GtkWidget*) _tmp50_, TRUE, TRUE, (guint) 0);
	_tmp51_ = (GtkGrid*) gtk_grid_new ();
	_tmp52_ = g_object_ref_sink (_tmp51_);
	grid = _tmp52_;
	gtk_box_pack_start ((GtkBox*) vbox, (GtkWidget*) grid, FALSE, FALSE, (guint) 0);
	gtk_grid_set_column_homogeneous (grid, TRUE);
	gtk_grid_set_column_spacing (grid, 2);
	gtk_widget_set_margin_left ((GtkWidget*) grid, 10);
	gtk_widget_set_margin_right ((GtkWidget*) grid, 10);
	gtk_widget_set_margin_bottom ((GtkWidget*) grid, 30);
	gtk_widget_set_margin_top ((GtkWidget*) grid, 200);
	_tmp53_ = _ ("CPU:");
	_tmp54_ = (GtkLabel*) gtk_label_new (_tmp53_);
	_tmp55_ = g_object_ref_sink (_tmp54_);
	label = _tmp55_;
	_tmp56_ = label;
	_tmp57_ = gtk_widget_get_style_context ((GtkWidget*) _tmp56_);
	gtk_style_context_add_class (_tmp57_, "boxes-graph-label");
	_tmp58_ = label;
	gtk_grid_attach (grid, (GtkWidget*) _tmp58_, 0, 0, 1, 1);
	_tmp59_ = g_new0 (gdouble, 0);
	_tmp60_ = _tmp59_;
	_tmp60__length1 = 0;
	_tmp61_ = boxes_mini_graph_new_with_ymax (_tmp60_, 0, 100.0, 20);
	_tmp62_ = g_object_ref_sink (_tmp61_);
	_g_object_unref0 (self->priv->cpu);
	self->priv->cpu = _tmp62_;
	_tmp60_ = (g_free (_tmp60_), NULL);
	_tmp63_ = self->priv->cpu;
	gtk_widget_set_hexpand ((GtkWidget*) _tmp63_, TRUE);
	_tmp64_ = self->priv->cpu;
	gtk_grid_attach (grid, (GtkWidget*) _tmp64_, 1, 0, 1, 1);
	_tmp65_ = _ ("I/O:");
	_tmp66_ = (GtkLabel*) gtk_label_new (_tmp65_);
	_tmp67_ = g_object_ref_sink (_tmp66_);
	_g_object_unref0 (label);
	label = _tmp67_;
	_tmp68_ = label;
	_tmp69_ = gtk_widget_get_style_context ((GtkWidget*) _tmp68_);
	gtk_style_context_add_class (_tmp69_, "boxes-graph-label");
	_tmp70_ = label;
	gtk_grid_attach (grid, (GtkWidget*) _tmp70_, 2, 0, 1, 1);
	_tmp71_ = g_new0 (gdouble, 0);
	_tmp72_ = _tmp71_;
	_tmp72__length1 = 0;
	_tmp73_ = boxes_mini_graph_new (_tmp72_, 0, 20);
	_tmp74_ = g_object_ref_sink (_tmp73_);
	_g_object_unref0 (self->priv->io);
	self->priv->io = _tmp74_;
	_tmp72_ = (g_free (_tmp72_), NULL);
	_tmp75_ = self->priv->io;
	gtk_widget_set_hexpand ((GtkWidget*) _tmp75_, TRUE);
	_tmp76_ = self->priv->io;
	gtk_grid_attach (grid, (GtkWidget*) _tmp76_, 3, 0, 1, 1);
	_tmp77_ = _ ("Net:");
	_tmp78_ = (GtkLabel*) gtk_label_new (_tmp77_);
	_tmp79_ = g_object_ref_sink (_tmp78_);
	_g_object_unref0 (label);
	label = _tmp79_;
	_tmp80_ = label;
	_tmp81_ = gtk_widget_get_style_context ((GtkWidget*) _tmp80_);
	gtk_style_context_add_class (_tmp81_, "boxes-graph-label");
	_tmp82_ = label;
	gtk_grid_attach (grid, (GtkWidget*) _tmp82_, 4, 0, 1, 1);
	_tmp83_ = g_new0 (gdouble, 0);
	_tmp84_ = _tmp83_;
	_tmp84__length1 = 0;
	_tmp85_ = boxes_mini_graph_new (_tmp84_, 0, 20);
	_tmp86_ = g_object_ref_sink (_tmp85_);
	_g_object_unref0 (self->priv->net);
	self->priv->net = _tmp86_;
	_tmp84_ = (g_free (_tmp84_), NULL);
	_tmp87_ = self->priv->net;
	gtk_widget_set_hexpand ((GtkWidget*) _tmp87_, TRUE);
	_tmp88_ = self->priv->net;
	gtk_grid_attach (grid, (GtkWidget*) _tmp88_, 5, 0, 1, 1);
	gtk_widget_show_all ((GtkWidget*) vbox);
	_tmp89_ = self->priv->notebook;
	gtk_widget_show_all ((GtkWidget*) _tmp89_);
	_g_object_unref0 (label);
	_g_object_unref0 (grid);
	_g_object_unref0 (renderer);
	_g_object_unref0 (selection);
	_g_object_unref0 (vbox);
	_g_object_unref0 (box);
	_g_object_unref0 (toolbar_box);
	_g_object_unref0 (toolbar);
	_g_object_unref0 (hbox);
}


static void boxes_properties_real_ui_state_changed (BoxesUI* base) {
	BoxesProperties * self;
	gulong _tmp0_;
	BoxesUIState _tmp4_;
	BoxesUIState _tmp5_;
	self = (BoxesProperties*) base;
	_tmp0_ = self->priv->stats_id;
	if (_tmp0_ != ((gulong) 0)) {
		BoxesApp* _tmp1_;
		BoxesCollectionItem* _tmp2_;
		gulong _tmp3_;
		_tmp1_ = self->priv->app;
		_tmp2_ = _tmp1_->current_item;
		_tmp3_ = self->priv->stats_id;
		g_signal_handler_disconnect ((GObject*) _tmp2_, _tmp3_);
		self->priv->stats_id = (gulong) 0;
	}
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) self);
	_tmp5_ = _tmp4_;
	switch (_tmp5_) {
		case BOXES_UI_STATE_PROPERTIES:
		{
			BoxesApp* _tmp6_;
			BoxesCollectionItem* _tmp7_;
			GtkLabel* _tmp8_;
			GBinding* _tmp9_ = NULL;
			GBinding* _tmp10_;
			_tmp6_ = self->priv->app;
			_tmp7_ = _tmp6_->current_item;
			_tmp8_ = self->priv->toolbar_label;
			_tmp9_ = g_object_bind_property_with_closures ((GObject*) _tmp7_, "name", (GObject*) _tmp8_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
			_tmp10_ = _g_object_ref0 (_tmp9_);
			_g_object_unref0 (self->priv->toolbar_label_bind);
			self->priv->toolbar_label_bind = _tmp10_;
			boxes_properties_populate (self);
			break;
		}
		default:
		break;
	}
}


static ClutterActor* boxes_properties_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesProperties* self;
	GtkClutterActor* _tmp0_;
	self = (BoxesProperties*) base;
	_tmp0_ = self->priv->gtk_actor;
	result = (ClutterActor*) _tmp0_;
	return result;
}


static gpointer _boxes_pair_ref0 (gpointer self) {
	return self ? boxes_pair_ref (self) : NULL;
}


static void _boxes_pair_unref0_ (gpointer var) {
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
	g_list_free (self);
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine) {
	BoxesPropertiesPageWidget* self = NULL;
	BoxesPropertiesPage _tmp0_;
	GtkGrid* _tmp9_;
	GtkGrid* _tmp10_;
	GtkGrid* _tmp11_;
	GtkGrid* _tmp12_;
	GtkGrid* _tmp13_;
	GtkGrid* _tmp14_;
	const gchar* _tmp15_;
	GtkLabel* _tmp16_;
	GtkLabel* _tmp17_;
	GtkLabel* label;
	GtkLabel* _tmp18_;
	GtkStyleContext* _tmp19_ = NULL;
	GtkLabel* _tmp20_;
	GtkLabel* _tmp21_;
	GtkLabel* _tmp22_;
	GtkGrid* _tmp23_;
	GtkLabel* _tmp24_;
	BoxesMachine* _tmp25_;
	BoxesPropertiesPage _tmp26_;
	GList* _tmp27_ = NULL;
	GList* properties;
	GList* _tmp28_;
	guint _tmp29_ = 0U;
	gboolean _tmp30_;
	GtkGrid* _tmp52_;
	GtkGrid* _tmp53_;
	GtkWidget* _tmp54_;
	g_return_val_if_fail (machine != NULL, NULL);
	self = (BoxesPropertiesPageWidget*) g_type_create_instance (object_type);
	_tmp0_ = page;
	switch (_tmp0_) {
		case BOXES_PROPERTIES_PAGE_LOGIN:
		{
			const gchar* _tmp1_ = NULL;
			gchar* _tmp2_;
			_tmp1_ = _ ("Login");
			_tmp2_ = g_strdup (_tmp1_);
			_g_free0 (self->name);
			self->name = _tmp2_;
			break;
		}
		case BOXES_PROPERTIES_PAGE_SYSTEM:
		{
			const gchar* _tmp3_ = NULL;
			gchar* _tmp4_;
			_tmp3_ = _ ("System");
			_tmp4_ = g_strdup (_tmp3_);
			_g_free0 (self->name);
			self->name = _tmp4_;
			break;
		}
		case BOXES_PROPERTIES_PAGE_DISPLAY:
		{
			const gchar* _tmp5_ = NULL;
			gchar* _tmp6_;
			_tmp5_ = _ ("Display");
			_tmp6_ = g_strdup (_tmp5_);
			_g_free0 (self->name);
			self->name = _tmp6_;
			break;
		}
		case BOXES_PROPERTIES_PAGE_DEVICES:
		{
			const gchar* _tmp7_ = NULL;
			gchar* _tmp8_;
			_tmp7_ = _ ("Devices");
			_tmp8_ = g_strdup (_tmp7_);
			_g_free0 (self->name);
			self->name = _tmp8_;
			break;
		}
		default:
		break;
	}
	_tmp9_ = (GtkGrid*) gtk_grid_new ();
	_tmp10_ = g_object_ref_sink (_tmp9_);
	_g_object_unref0 (self->priv->grid);
	self->priv->grid = _tmp10_;
	_tmp11_ = self->priv->grid;
	g_object_set ((GtkWidget*) _tmp11_, "margin", 20, NULL);
	_tmp12_ = self->priv->grid;
	gtk_grid_set_row_spacing (_tmp12_, 10);
	_tmp13_ = self->priv->grid;
	gtk_grid_set_column_spacing (_tmp13_, 20);
	_tmp14_ = self->priv->grid;
	gtk_widget_set_valign ((GtkWidget*) _tmp14_, GTK_ALIGN_START);
	_tmp15_ = self->name;
	_tmp16_ = (GtkLabel*) gtk_label_new (_tmp15_);
	_tmp17_ = g_object_ref_sink (_tmp16_);
	label = _tmp17_;
	_tmp18_ = label;
	_tmp19_ = gtk_widget_get_style_context ((GtkWidget*) _tmp18_);
	gtk_style_context_add_class (_tmp19_, "boxes-step-label");
	_tmp20_ = label;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp20_, 10);
	_tmp21_ = label;
	g_object_set ((GtkMisc*) _tmp21_, "xalign", 0.0f, NULL);
	_tmp22_ = label;
	gtk_widget_set_hexpand ((GtkWidget*) _tmp22_, FALSE);
	_tmp23_ = self->priv->grid;
	_tmp24_ = label;
	gtk_grid_attach (_tmp23_, (GtkWidget*) _tmp24_, 0, 0, 2, 1);
	_tmp25_ = machine;
	_tmp26_ = page;
	_tmp27_ = boxes_machine_get_properties (_tmp25_, _tmp26_);
	properties = _tmp27_;
	_tmp28_ = properties;
	_tmp29_ = g_list_length (_tmp28_);
	self->empty = _tmp29_ == ((guint) 0);
	_tmp30_ = self->empty;
	if (!_tmp30_) {
		gint current_row;
		GList* _tmp31_;
		current_row = 1;
		_tmp31_ = properties;
		{
			GList* property_collection = NULL;
			GList* property_it = NULL;
			property_collection = _tmp31_;
			for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
				BoxesPair* _tmp32_;
				BoxesPair* property = NULL;
				_tmp32_ = _boxes_pair_ref0 ((BoxesPair*) property_it->data);
				property = _tmp32_;
				{
					BoxesPair* _tmp33_;
					gconstpointer _tmp34_;
					GtkLabel* _tmp35_;
					GtkLabel* _tmp36_;
					GtkLabel* label_name;
					GtkLabel* _tmp37_;
					GdkColor _tmp38_ = {0};
					GtkLabel* _tmp39_;
					GtkLabel* _tmp40_;
					GtkLabel* _tmp41_;
					GtkGrid* _tmp42_;
					GtkLabel* _tmp43_;
					gint _tmp44_;
					BoxesPair* _tmp45_;
					gconstpointer _tmp46_;
					GtkWidget* _tmp47_;
					GtkWidget* widget;
					GtkGrid* _tmp48_;
					GtkWidget* _tmp49_;
					gint _tmp50_;
					gint _tmp51_;
					_tmp33_ = property;
					_tmp34_ = _tmp33_->first;
					_tmp35_ = (GtkLabel*) gtk_label_new ((const gchar*) _tmp34_);
					_tmp36_ = g_object_ref_sink (_tmp35_);
					label_name = _tmp36_;
					_tmp37_ = label_name;
					boxes_get_color ("grey", &_tmp38_);
					gtk_widget_modify_fg ((GtkWidget*) _tmp37_, GTK_STATE_NORMAL, &_tmp38_);
					_tmp39_ = label_name;
					gtk_widget_set_margin_left ((GtkWidget*) _tmp39_, 25);
					_tmp40_ = label_name;
					gtk_widget_set_halign ((GtkWidget*) _tmp40_, GTK_ALIGN_START);
					_tmp41_ = label_name;
					gtk_widget_set_hexpand ((GtkWidget*) _tmp41_, FALSE);
					_tmp42_ = self->priv->grid;
					_tmp43_ = label_name;
					_tmp44_ = current_row;
					gtk_grid_attach (_tmp42_, (GtkWidget*) _tmp43_, 0, _tmp44_, 1, 1);
					_tmp45_ = property;
					_tmp46_ = _tmp45_->second;
					_tmp47_ = _g_object_ref0 ((GtkWidget*) _tmp46_);
					widget = _tmp47_;
					_tmp48_ = self->priv->grid;
					_tmp49_ = widget;
					_tmp50_ = current_row;
					gtk_grid_attach (_tmp48_, _tmp49_, 1, _tmp50_, 1, 1);
					_tmp51_ = current_row;
					current_row = _tmp51_ + 1;
					_g_object_unref0 (widget);
					_g_object_unref0 (label_name);
					_boxes_pair_unref0 (property);
				}
			}
		}
	}
	_tmp52_ = self->priv->grid;
	gtk_widget_show_all ((GtkWidget*) _tmp52_);
	_tmp53_ = self->priv->grid;
	_tmp54_ = _g_object_ref0 ((GtkWidget*) _tmp53_);
	_g_object_unref0 (self->widget);
	self->widget = _tmp54_;
	__g_list_free__boxes_pair_unref0_0 (properties);
	_g_object_unref0 (label);
	return self;
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine) {
	return boxes_properties_page_widget_construct (BOXES_PROPERTIES_TYPE_PAGE_WIDGET, page, machine);
}


static void boxes_properties_value_page_widget_init (GValue* value) {
	value->data[0].v_pointer = NULL;
}


static void boxes_properties_value_page_widget_free_value (GValue* value) {
	if (value->data[0].v_pointer) {
		boxes_properties_page_widget_unref (value->data[0].v_pointer);
	}
}


static void boxes_properties_value_page_widget_copy_value (const GValue* src_value, GValue* dest_value) {
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = boxes_properties_page_widget_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}


static gpointer boxes_properties_value_page_widget_peek_pointer (const GValue* value) {
	return value->data[0].v_pointer;
}


static gchar* boxes_properties_value_page_widget_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	if (collect_values[0].v_pointer) {
		BoxesPropertiesPageWidget* object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = boxes_properties_page_widget_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}


static gchar* boxes_properties_value_page_widget_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesPropertiesPageWidget** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = boxes_properties_page_widget_ref (value->data[0].v_pointer);
	}
	return NULL;
}


static GParamSpec* boxes_properties_param_spec_page_widget (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesPropertiesParamSpecPageWidget* spec;
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_PROPERTIES_TYPE_PAGE_WIDGET), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}


static gpointer boxes_properties_value_get_page_widget (const GValue* value) {
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_PROPERTIES_TYPE_PAGE_WIDGET), NULL);
	return value->data[0].v_pointer;
}


static void boxes_properties_value_set_page_widget (GValue* value, gpointer v_object) {
	BoxesPropertiesPageWidget* old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_PROPERTIES_TYPE_PAGE_WIDGET));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_PROPERTIES_TYPE_PAGE_WIDGET));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		boxes_properties_page_widget_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		boxes_properties_page_widget_unref (old);
	}
}


static void boxes_properties_value_take_page_widget (GValue* value, gpointer v_object) {
	BoxesPropertiesPageWidget* old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_PROPERTIES_TYPE_PAGE_WIDGET));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_PROPERTIES_TYPE_PAGE_WIDGET));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		boxes_properties_page_widget_unref (old);
	}
}


static void boxes_properties_page_widget_class_init (BoxesPropertiesPageWidgetClass * klass) {
	boxes_properties_page_widget_parent_class = g_type_class_peek_parent (klass);
	BOXES_PROPERTIES_PAGE_WIDGET_CLASS (klass)->finalize = boxes_properties_page_widget_finalize;
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPageWidgetPrivate));
}


static void boxes_properties_page_widget_instance_init (BoxesPropertiesPageWidget * self) {
	self->priv = BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE (self);
	self->ref_count = 1;
}


static void boxes_properties_page_widget_finalize (BoxesPropertiesPageWidget* obj) {
	BoxesPropertiesPageWidget * self;
	self = BOXES_PROPERTIES_PAGE_WIDGET (obj);
	_g_object_unref0 (self->widget);
	_g_free0 (self->name);
	_g_object_unref0 (self->priv->grid);
}


static GType boxes_properties_page_widget_get_type (void) {
	static volatile gsize boxes_properties_page_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_widget_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_properties_value_page_widget_init, boxes_properties_value_page_widget_free_value, boxes_properties_value_page_widget_copy_value, boxes_properties_value_page_widget_peek_pointer, "p", boxes_properties_value_page_widget_collect_value, "p", boxes_properties_value_page_widget_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesPageWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_page_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesPageWidget), 0, (GInstanceInitFunc) boxes_properties_page_widget_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_properties_page_widget_type_id;
		boxes_properties_page_widget_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesPropertiesPageWidget", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_properties_page_widget_type_id__volatile, boxes_properties_page_widget_type_id);
	}
	return boxes_properties_page_widget_type_id__volatile;
}


static gpointer boxes_properties_page_widget_ref (gpointer instance) {
	BoxesPropertiesPageWidget* self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}


static void boxes_properties_page_widget_unref (gpointer instance) {
	BoxesPropertiesPageWidget* self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}


static void boxes_properties_class_init (BoxesPropertiesClass * klass) {
	boxes_properties_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPrivate));
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_properties_real_ui_state_changed;
	BOXES_UI_CLASS (klass)->get_actor = boxes_properties_real_get_actor;
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_properties_get_property;
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void boxes_properties_instance_init (BoxesProperties * self) {
	self->priv = BOXES_PROPERTIES_GET_PRIVATE (self);
}


static void boxes_properties_finalize (GObject* obj) {
	BoxesProperties * self;
	self = BOXES_PROPERTIES (obj);
	_g_object_unref0 (self->priv->gtk_actor);
	_g_object_unref0 (self->priv->app);
	_g_object_unref0 (self->priv->notebook);
	_g_object_unref0 (self->priv->back);
	_g_object_unref0 (self->priv->toolbar_label);
	_g_object_unref0 (self->priv->listmodel);
	_g_object_unref0 (self->priv->tree_view);
	_g_object_unref0 (self->priv->toolbar_label_bind);
	_g_object_unref0 (self->priv->cpu);
	_g_object_unref0 (self->priv->io);
	_g_object_unref0 (self->priv->net);
	G_OBJECT_CLASS (boxes_properties_parent_class)->finalize (obj);
}


GType boxes_properties_get_type (void) {
	static volatile gsize boxes_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesProperties), 0, (GInstanceInitFunc) boxes_properties_instance_init, NULL };
		GType boxes_properties_type_id;
		boxes_properties_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesProperties", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_type_id__volatile, boxes_properties_type_id);
	}
	return boxes_properties_type_id__volatile;
}


static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = BOXES_PROPERTIES (object);
	switch (property_id) {
		case BOXES_PROPERTIES_ACTOR:
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



