/* wizard-source.c generated by valac 0.16.0.2-f2187, the Vala compiler
 * generated from wizard-source.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <osinfo/osinfo.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>
#include <cairo.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>


#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_WIZARD_SCROLLED (boxes_wizard_scrolled_get_type ())
#define BOXES_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled))
#define BOXES_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))
#define BOXES_IS_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_IS_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_WIZARD_SCROLLED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))

typedef struct _BoxesWizardScrolled BoxesWizardScrolled;
typedef struct _BoxesWizardScrolledClass BoxesWizardScrolledClass;
typedef struct _BoxesWizardScrolledPrivate BoxesWizardScrolledPrivate;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesWizardSourceAddMediaEntriesData BoxesWizardSourceAddMediaEntriesData;
typedef struct _Block35Data Block35Data;
typedef struct _Block36Data Block36Data;
typedef struct _Block37Data Block37Data;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

typedef void (*ClickedFunc) (void* user_data);
struct _BoxesWizardScrolled {
	GtkScrolledWindow parent_instance;
	BoxesWizardScrolledPrivate * priv;
};

struct _BoxesWizardScrolledClass {
	GtkScrolledWindowClass parent_class;
};

struct _BoxesWizardScrolledPrivate {
	gint num_visible;
};

struct _BoxesWizardSource {
	GObject parent_instance;
	BoxesWizardSourcePrivate * priv;
	GtkEntry* url_entry;
};

struct _BoxesWizardSourceClass {
	GObjectClass parent_class;
};

struct _BoxesWizardSourcePrivate {
	BoxesSourcePage _page;
	BoxesInstallerMedia* _install_media;
	GtkBox* main_vbox;
	GtkBox* media_vbox;
	GtkScrolledWindow* media_scrolled;
	GtkNotebook* notebook;
	GtkLabel* url_label;
	GtkImage* url_image;
	BoxesMediaManager* media_manager;
	BoxesApp* app;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
};

struct _BoxesWizardSourceAddMediaEntriesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizardSource* self;
	BoxesMediaManager* _tmp0_;
	GList* _tmp1_;
	GList* medias;
	GtkBox* _tmp2_;
	GList* _tmp3_;
	GList* child_collection;
	GList* child_it;
	GtkWidget* child;
	GtkWidget* _tmp4_;
	gconstpointer _tmp5_;
	gchar* _tmp6_;
	gchar* child_media;
	const gchar* _tmp7_;
	gboolean obsolete;
	GList* _tmp8_;
	GList* media_collection;
	GList* media_it;
	BoxesInstallerMedia* _tmp9_;
	BoxesInstallerMedia* media;
	const gchar* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	const gchar* _tmp12_;
	gboolean _tmp13_;
	GtkBox* _tmp14_;
	GtkWidget* _tmp15_;
	GList* _tmp16_;
	GList* _vala1_media_collection;
	GList* _vala1_media_it;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _vala1_media;
	gboolean nouveau;
	GtkBox* _tmp18_;
	GList* _tmp19_;
	GList* _vala1_child_collection;
	GList* _vala1_child_it;
	GtkWidget* _vala1_child;
	GtkWidget* _tmp20_;
	gconstpointer _tmp21_;
	gchar* _tmp22_;
	gchar* _vala1_child_media;
	gboolean _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesInstallerMedia* _tmp26_;
	const gchar* _tmp27_;
	gboolean _tmp28_;
	gboolean _tmp29_;
	BoxesInstallerMedia* _tmp30_;
	GtkBox* _tmp31_;
	GList* _tmp32_;
	GList* _tmp33_;
	guint _tmp34_;
	gboolean _tmp35_;
	GtkScrolledWindow* _tmp36_;
};

struct _Block35Data {
	int _ref_count_;
	BoxesWizardSource * self;
	BoxesInstallerMedia* media;
};

struct _Block36Data {
	int _ref_count_;
	BoxesWizardSource * self;
	ClickedFunc clicked;
	gpointer clicked_target;
	GDestroyNotify clicked_target_destroy_notify;
};

struct _Block37Data {
	int _ref_count_;
	Block36Data * _data36_;
	GtkAlignment* bin;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterState* state;
	ClutterBox* box;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};


static gpointer boxes_wizard_scrolled_parent_class = NULL;
static gpointer boxes_wizard_source_parent_class = NULL;

GType boxes_source_page_get_type (void) G_GNUC_CONST;
GType boxes_wizard_scrolled_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SCROLLED_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledPrivate))
enum  {
	BOXES_WIZARD_SCROLLED_DUMMY_PROPERTY
};
BoxesWizardScrolled* boxes_wizard_scrolled_new (gint num_visible);
BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type, gint num_visible);
static void __lambda47_ (BoxesWizardScrolled* self);
static void ___lambda47__gtk_widget_show (GtkWidget* _sender, gpointer self);
static void __lambda48_ (BoxesWizardScrolled* self);
static void ___lambda48__gtk_widget_hide (GtkWidget* _sender, gpointer self);
static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height);
static void boxes_wizard_scrolled_finalize (GObject* obj);
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourcePrivate))
enum  {
	BOXES_WIZARD_SOURCE_DUMMY_PROPERTY,
	BOXES_WIZARD_SOURCE_WIDGET,
	BOXES_WIZARD_SOURCE_PAGE,
	BOXES_WIZARD_SOURCE_URI,
	BOXES_WIZARD_SOURCE_INSTALL_MEDIA
};
BoxesWizardSource* boxes_wizard_source_new (BoxesApp* app, BoxesMediaManager* media_manager);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type, BoxesApp* app, BoxesMediaManager* media_manager);
static GtkBox* boxes_wizard_source_add_entry (BoxesWizardSource* self, GtkBox* box, ClickedFunc clicked, void* clicked_target, GDestroyNotify clicked_target_destroy_notify, gint h_margin, gint v_margin, const gchar* media);
static void __lambda51_ (BoxesWizardSource* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
static void ___lambda51__clicked_func (gpointer self);
static void boxes_wizard_source_launch_file_selection_dialog (BoxesWizardSource* self);
static void _boxes_wizard_source_launch_file_selection_dialog_clicked_func (gpointer self);
static void __lambda53_ (BoxesWizardSource* self);
static void ___lambda53__clicked_func (gpointer self);
static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
static void boxes_wizard_source_add_media_entries_data_free (gpointer _data);
static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static Block35Data* block35_data_ref (Block35Data* _data35_);
static void block35_data_unref (void * _userdata_);
static void __lambda52_ (Block35Data* _data35_);
static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
static void ___lambda52__clicked_func (gpointer self);
GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size);
static Block36Data* block36_data_ref (Block36Data* _data36_);
static void block36_data_unref (void * _userdata_);
static void ___lambda49_ (Block36Data* _data36_);
static void ____lambda49__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block37Data* block37_data_ref (Block37Data* _data37_);
static void block37_data_unref (void * _userdata_);
static gboolean ___lambda50_ (Block37Data* _data37_, cairo_t* cr);
static gboolean ____lambda50__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GtkWidget* boxes_wizard_source_get_widget (BoxesWizardSource* self);
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static void boxes_wizard_source_finalize (GObject* obj);
static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_source_page_get_type (void) {
	static volatile gsize boxes_source_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_source_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SOURCE_PAGE_MAIN, "BOXES_SOURCE_PAGE_MAIN", "main"}, {BOXES_SOURCE_PAGE_URL, "BOXES_SOURCE_PAGE_URL", "url"}, {BOXES_SOURCE_PAGE_LAST, "BOXES_SOURCE_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_source_page_type_id;
		boxes_source_page_type_id = g_enum_register_static ("BoxesSourcePage", values);
		g_once_init_leave (&boxes_source_page_type_id__volatile, boxes_source_page_type_id);
	}
	return boxes_source_page_type_id__volatile;
}


static void __lambda47_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_ = NULL;
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_add_class (_tmp0_, "boxes-menu-scrolled");
	gtk_widget_reset_style ((GtkWidget*) self);
}


static void ___lambda47__gtk_widget_show (GtkWidget* _sender, gpointer self) {
	__lambda47_ (self);
}


static void __lambda48_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_ = NULL;
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_remove_class (_tmp0_, "boxes-menu-scrolled");
	gtk_widget_reset_style ((GtkWidget*) self);
}


static void ___lambda48__gtk_widget_hide (GtkWidget* _sender, gpointer self) {
	__lambda48_ (self);
}


BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type, gint num_visible) {
	BoxesWizardScrolled * self = NULL;
	gint _tmp0_;
	GtkStyleContext* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	self = (BoxesWizardScrolled*) g_object_new (object_type, NULL);
	_tmp0_ = num_visible;
	self->priv->num_visible = _tmp0_;
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
	gtk_style_context_add_class (_tmp1_, "boxes-menu-scrolled");
	gtk_scrolled_window_set_policy ((GtkScrolledWindow*) self, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
	_tmp2_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
	g_signal_connect_object (_tmp2_, "show", (GCallback) ___lambda47__gtk_widget_show, self, 0);
	_tmp3_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
	g_signal_connect_object (_tmp3_, "hide", (GCallback) ___lambda48__gtk_widget_hide, self, 0);
	return self;
}


BoxesWizardScrolled* boxes_wizard_scrolled_new (gint num_visible) {
	return boxes_wizard_scrolled_construct (BOXES_TYPE_WIZARD_SCROLLED, num_visible);
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height) {
	BoxesWizardScrolled * self;
	gint _vala_minimum_height = 0;
	gint _vala_natural_height = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GtkWidget* _tmp2_ = NULL;
	GtkViewport* _tmp3_;
	GtkViewport* viewport;
	GtkViewport* _tmp4_;
	GtkWidget* _tmp5_ = NULL;
	GtkBox* _tmp6_;
	GtkBox* box;
	gint height;
	gint i;
	GtkBox* _tmp7_;
	GList* _tmp8_ = NULL;
	gint _tmp18_;
	gint _tmp19_;
	gint _tmp20_ = 0;
	gint _tmp21_;
	gint _tmp22_;
	gint _tmp23_ = 0;
	self = (BoxesWizardScrolled*) base;
	GTK_WIDGET_CLASS (boxes_wizard_scrolled_parent_class)->get_preferred_height ((GtkWidget*) GTK_SCROLLED_WINDOW (self), &_tmp0_, &_tmp1_);
	_vala_minimum_height = _tmp0_;
	_vala_natural_height = _tmp1_;
	_tmp2_ = gtk_bin_get_child ((GtkBin*) self);
	_tmp3_ = _g_object_ref0 (GTK_IS_VIEWPORT (_tmp2_) ? ((GtkViewport*) _tmp2_) : NULL);
	viewport = _tmp3_;
	_tmp4_ = viewport;
	_tmp5_ = gtk_bin_get_child ((GtkBin*) _tmp4_);
	_tmp6_ = _g_object_ref0 (GTK_IS_BOX (_tmp5_) ? ((GtkBox*) _tmp5_) : NULL);
	box = _tmp6_;
	height = 0;
	i = 0;
	_tmp7_ = box;
	_tmp8_ = gtk_container_get_children ((GtkContainer*) _tmp7_);
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
		w_collection = _tmp8_;
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
			GtkWidget* w = NULL;
			w = (GtkWidget*) w_it->data;
			{
				GtkWidget* _tmp9_;
				gboolean _tmp10_ = FALSE;
				gint child_height = 0;
				GtkWidget* _tmp11_;
				gint _tmp12_ = 0;
				gint _tmp13_;
				gint _tmp14_;
				gint _tmp15_;
				gint _tmp16_;
				gint _tmp17_;
				_tmp9_ = w;
				_tmp10_ = gtk_widget_get_visible (_tmp9_);
				if (!_tmp10_) {
					continue;
				}
				_tmp11_ = w;
				gtk_widget_get_preferred_height (_tmp11_, NULL, &_tmp12_);
				child_height = _tmp12_;
				_tmp13_ = height;
				_tmp14_ = child_height;
				height = _tmp13_ + _tmp14_;
				_tmp15_ = i;
				i = _tmp15_ + 1;
				_tmp16_ = i;
				_tmp17_ = self->priv->num_visible;
				if (_tmp16_ == _tmp17_) {
					break;
				}
			}
		}
		_g_list_free0 (w_collection);
	}
	_tmp18_ = _vala_minimum_height;
	_tmp19_ = height;
	_tmp20_ = MAX (_tmp18_, _tmp19_);
	_vala_minimum_height = _tmp20_;
	_tmp21_ = _vala_natural_height;
	_tmp22_ = height;
	_tmp23_ = MAX (_tmp21_, _tmp22_);
	_vala_natural_height = _tmp23_;
	_g_object_unref0 (box);
	_g_object_unref0 (viewport);
	if (minimum_height) {
		*minimum_height = _vala_minimum_height;
	}
	if (natural_height) {
		*natural_height = _vala_natural_height;
	}
}


static void boxes_wizard_scrolled_class_init (BoxesWizardScrolledClass * klass) {
	boxes_wizard_scrolled_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (BoxesWizardScrolledPrivate));
	GTK_WIDGET_CLASS (klass)->get_preferred_height = boxes_wizard_scrolled_real_get_preferred_height;
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_scrolled_finalize;
}


static void boxes_wizard_scrolled_instance_init (BoxesWizardScrolled * self) {
	self->priv = BOXES_WIZARD_SCROLLED_GET_PRIVATE (self);
}


static void boxes_wizard_scrolled_finalize (GObject* obj) {
	BoxesWizardScrolled * self;
	self = BOXES_WIZARD_SCROLLED (obj);
	G_OBJECT_CLASS (boxes_wizard_scrolled_parent_class)->finalize (obj);
}


GType boxes_wizard_scrolled_get_type (void) {
	static volatile gsize boxes_wizard_scrolled_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_scrolled_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardScrolledClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_scrolled_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardScrolled), 0, (GInstanceInitFunc) boxes_wizard_scrolled_instance_init, NULL };
		GType boxes_wizard_scrolled_type_id;
		boxes_wizard_scrolled_type_id = g_type_register_static (GTK_TYPE_SCROLLED_WINDOW, "BoxesWizardScrolled", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_scrolled_type_id__volatile, boxes_wizard_scrolled_type_id);
	}
	return boxes_wizard_scrolled_type_id__volatile;
}


static void __lambda51_ (BoxesWizardSource* self) {
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
}


static void ___lambda51__clicked_func (gpointer self) {
	__lambda51_ (self);
}


static void _boxes_wizard_source_launch_file_selection_dialog_clicked_func (gpointer self) {
	boxes_wizard_source_launch_file_selection_dialog (self);
}


static void __lambda53_ (BoxesWizardSource* self) {
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_MAIN);
}


static void ___lambda53__clicked_func (gpointer self) {
	__lambda53_ (self);
}


BoxesWizardSource* boxes_wizard_source_construct (GType object_type, BoxesApp* app, BoxesMediaManager* media_manager) {
	BoxesWizardSource * self = NULL;
	BoxesApp* _tmp0_;
	BoxesApp* _tmp1_;
	BoxesMediaManager* _tmp2_;
	BoxesMediaManager* _tmp3_;
	GtkNotebook* _tmp4_;
	GtkNotebook* _tmp5_;
	GtkNotebook* _tmp6_;
	GtkNotebook* _tmp7_;
	GtkStyleContext* _tmp8_ = NULL;
	GtkNotebook* _tmp9_;
	GtkBox* _tmp10_;
	GtkBox* _tmp11_;
	GtkBox* _tmp12_;
	GtkStyleContext* _tmp13_ = NULL;
	GtkBox* _tmp14_;
	GtkBox* _tmp15_;
	GtkBox* _tmp16_;
	GtkNotebook* _tmp17_;
	GtkBox* _tmp18_;
	BoxesWizardScrolled* _tmp19_;
	GtkScrolledWindow* _tmp20_;
	GtkBox* _tmp21_;
	GtkBox* _tmp22_;
	GtkScrolledWindow* _tmp23_;
	GtkScrolledWindow* _tmp24_;
	GtkBox* _tmp25_;
	GtkBox* _tmp26_;
	GtkScrolledWindow* _tmp27_;
	GtkBox* _tmp28_;
	GtkBox* _tmp29_ = NULL;
	GtkBox* hbox;
	const gchar* _tmp30_ = NULL;
	GtkLabel* _tmp31_;
	GtkLabel* _tmp32_;
	GtkLabel* label;
	GtkLabel* _tmp33_;
	GtkBox* _tmp34_;
	GtkLabel* _tmp35_;
	GtkLabel* _tmp36_;
	GtkLabel* _tmp37_;
	GtkLabel* next;
	GtkBox* _tmp38_;
	GtkLabel* _tmp39_;
	GtkBox* _tmp40_;
	GtkBox* _tmp41_ = NULL;
	const gchar* _tmp42_ = NULL;
	GtkLabel* _tmp43_;
	GtkLabel* _tmp44_;
	GtkLabel* _tmp45_;
	GtkBox* _tmp46_;
	GtkLabel* _tmp47_;
	GtkLabel* _tmp48_;
	GtkLabel* _tmp49_;
	GtkBox* _tmp50_;
	GtkLabel* _tmp51_;
	GtkBox* _tmp52_;
	GtkBox* _tmp53_;
	GtkBox* url_menubox;
	GtkStyleContext* _tmp54_ = NULL;
	GtkNotebook* _tmp55_;
	GtkBox* _tmp56_ = NULL;
	GtkLabel* _tmp57_;
	GtkLabel* _tmp58_;
	GtkLabel* prev;
	GtkBox* _tmp59_;
	const gchar* _tmp60_ = NULL;
	GtkLabel* _tmp61_;
	GtkLabel* _tmp62_;
	GtkLabel* _tmp63_;
	GtkStyleContext* _tmp64_ = NULL;
	GtkBox* _tmp65_;
	GtkLabel* _tmp66_;
	GtkBox* _tmp67_ = NULL;
	GtkBox* vbox;
	GtkEntry* _tmp68_;
	GtkEntry* _tmp69_;
	GtkEntry* _tmp70_;
	GtkBox* _tmp71_;
	GtkBox* _tmp72_;
	GtkImage* _tmp73_;
	GtkImage* _tmp74_;
	GtkImage* _tmp75_;
	GtkBox* _tmp76_;
	GtkImage* _tmp77_;
	GtkLabel* _tmp78_;
	GtkLabel* _tmp79_;
	GtkLabel* _tmp80_;
	GtkLabel* _tmp81_;
	const gchar* _tmp82_ = NULL;
	GtkLabel* _tmp83_;
	GtkLabel* _tmp84_;
	GtkBox* _tmp85_;
	GtkLabel* _tmp86_;
	GtkBox* _tmp87_;
	GtkNotebook* _tmp88_;
	g_return_val_if_fail (app != NULL, NULL);
	g_return_val_if_fail (media_manager != NULL, NULL);
	self = (BoxesWizardSource*) g_object_new (object_type, NULL);
	_tmp0_ = app;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->priv->app);
	self->priv->app = _tmp1_;
	_tmp2_ = media_manager;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	_g_object_unref0 (self->priv->media_manager);
	self->priv->media_manager = _tmp3_;
	_tmp4_ = (GtkNotebook*) gtk_notebook_new ();
	_tmp5_ = g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->notebook);
	self->priv->notebook = _tmp5_;
	_tmp6_ = self->priv->notebook;
	g_object_set ((GtkWidget*) _tmp6_, "width-request", 500, NULL);
	_tmp7_ = self->priv->notebook;
	_tmp8_ = gtk_widget_get_style_context ((GtkWidget*) _tmp7_);
	gtk_style_context_add_class (_tmp8_, "boxes-source-nb");
	_tmp9_ = self->priv->notebook;
	gtk_notebook_set_show_tabs (_tmp9_, FALSE);
	_tmp10_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	_tmp11_ = g_object_ref_sink (_tmp10_);
	_g_object_unref0 (self->priv->main_vbox);
	self->priv->main_vbox = _tmp11_;
	_tmp12_ = self->priv->main_vbox;
	_tmp13_ = gtk_widget_get_style_context ((GtkWidget*) _tmp12_);
	gtk_style_context_add_class (_tmp13_, "boxes-menu");
	_tmp14_ = self->priv->main_vbox;
	_tmp15_ = self->priv->main_vbox;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp15_, 15);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp14_, 15);
	_tmp16_ = self->priv->main_vbox;
	gtk_widget_grab_focus ((GtkWidget*) _tmp16_);
	_tmp17_ = self->priv->notebook;
	_tmp18_ = self->priv->main_vbox;
	gtk_notebook_append_page (_tmp17_, (GtkWidget*) _tmp18_, NULL);
	_tmp19_ = boxes_wizard_scrolled_new (6);
	_tmp20_ = (GtkScrolledWindow*) g_object_ref_sink (_tmp19_);
	_g_object_unref0 (self->priv->media_scrolled);
	self->priv->media_scrolled = _tmp20_;
	_tmp21_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	_tmp22_ = g_object_ref_sink (_tmp21_);
	_g_object_unref0 (self->priv->media_vbox);
	self->priv->media_vbox = _tmp22_;
	_tmp23_ = self->priv->media_scrolled;
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp23_, TRUE);
	_tmp24_ = self->priv->media_scrolled;
	_tmp25_ = self->priv->media_vbox;
	gtk_scrolled_window_add_with_viewport (_tmp24_, (GtkWidget*) _tmp25_);
	_tmp26_ = self->priv->main_vbox;
	_tmp27_ = self->priv->media_scrolled;
	gtk_container_add ((GtkContainer*) _tmp26_, (GtkWidget*) _tmp27_);
	_tmp28_ = self->priv->main_vbox;
	_tmp29_ = boxes_wizard_source_add_entry (self, _tmp28_, ___lambda51__clicked_func, g_object_ref (self), g_object_unref, 20, 10, NULL);
	hbox = _tmp29_;
	_tmp30_ = _ ("Enter URL");
	_tmp31_ = (GtkLabel*) gtk_label_new (_tmp30_);
	_tmp32_ = g_object_ref_sink (_tmp31_);
	label = _tmp32_;
	_tmp33_ = label;
	g_object_set ((GtkMisc*) _tmp33_, "xalign", 0.0f, NULL);
	_tmp34_ = hbox;
	_tmp35_ = label;
	gtk_box_pack_start (_tmp34_, (GtkWidget*) _tmp35_, TRUE, TRUE, (guint) 0);
	_tmp36_ = (GtkLabel*) gtk_label_new ("▶");
	_tmp37_ = g_object_ref_sink (_tmp36_);
	next = _tmp37_;
	_tmp38_ = hbox;
	_tmp39_ = next;
	gtk_box_pack_start (_tmp38_, (GtkWidget*) _tmp39_, FALSE, FALSE, (guint) 0);
	_tmp40_ = self->priv->main_vbox;
	_tmp41_ = boxes_wizard_source_add_entry (self, _tmp40_, _boxes_wizard_source_launch_file_selection_dialog_clicked_func, g_object_ref (self), g_object_unref, 20, 10, NULL);
	_g_object_unref0 (hbox);
	hbox = _tmp41_;
	_tmp42_ = _ ("Select a file");
	_tmp43_ = (GtkLabel*) gtk_label_new (_tmp42_);
	_tmp44_ = g_object_ref_sink (_tmp43_);
	_g_object_unref0 (label);
	label = _tmp44_;
	_tmp45_ = label;
	g_object_set ((GtkMisc*) _tmp45_, "xalign", 0.0f, NULL);
	_tmp46_ = hbox;
	_tmp47_ = label;
	gtk_box_pack_start (_tmp46_, (GtkWidget*) _tmp47_, TRUE, TRUE, (guint) 0);
	_tmp48_ = (GtkLabel*) gtk_label_new ("▶");
	_tmp49_ = g_object_ref_sink (_tmp48_);
	_g_object_unref0 (next);
	next = _tmp49_;
	_tmp50_ = hbox;
	_tmp51_ = next;
	gtk_box_pack_start (_tmp50_, (GtkWidget*) _tmp51_, FALSE, FALSE, (guint) 0);
	_tmp52_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	_tmp53_ = g_object_ref_sink (_tmp52_);
	url_menubox = _tmp53_;
	_tmp54_ = gtk_widget_get_style_context ((GtkWidget*) url_menubox);
	gtk_style_context_add_class (_tmp54_, "boxes-menu");
	gtk_widget_set_margin_bottom ((GtkWidget*) url_menubox, 15);
	gtk_widget_set_margin_top ((GtkWidget*) url_menubox, 15);
	_tmp55_ = self->priv->notebook;
	gtk_notebook_append_page (_tmp55_, (GtkWidget*) url_menubox, NULL);
	_tmp56_ = boxes_wizard_source_add_entry (self, url_menubox, ___lambda53__clicked_func, g_object_ref (self), g_object_unref, 20, 10, NULL);
	_g_object_unref0 (hbox);
	hbox = _tmp56_;
	_tmp57_ = (GtkLabel*) gtk_label_new ("◀");
	_tmp58_ = g_object_ref_sink (_tmp57_);
	prev = _tmp58_;
	_tmp59_ = hbox;
	gtk_box_pack_start (_tmp59_, (GtkWidget*) prev, FALSE, FALSE, (guint) 0);
	_tmp60_ = _ ("Enter URL");
	_tmp61_ = (GtkLabel*) gtk_label_new (_tmp60_);
	_tmp62_ = g_object_ref_sink (_tmp61_);
	_g_object_unref0 (label);
	label = _tmp62_;
	_tmp63_ = label;
	_tmp64_ = gtk_widget_get_style_context ((GtkWidget*) _tmp63_);
	gtk_style_context_add_class (_tmp64_, "boxes-source-label");
	_tmp65_ = hbox;
	_tmp66_ = label;
	gtk_box_pack_start (_tmp65_, (GtkWidget*) _tmp66_, TRUE, TRUE, (guint) 0);
	_tmp67_ = boxes_wizard_source_add_entry (self, url_menubox, NULL, NULL, NULL, 20, 10, NULL);
	vbox = _tmp67_;
	gtk_orientable_set_orientation ((GtkOrientable*) vbox, GTK_ORIENTATION_VERTICAL);
	_tmp68_ = (GtkEntry*) gtk_entry_new ();
	_tmp69_ = g_object_ref_sink (_tmp68_);
	_g_object_unref0 (self->url_entry);
	self->url_entry = _tmp69_;
	_tmp70_ = self->url_entry;
	gtk_container_add ((GtkContainer*) vbox, (GtkWidget*) _tmp70_);
	_tmp71_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	_tmp72_ = g_object_ref_sink (_tmp71_);
	_g_object_unref0 (hbox);
	hbox = _tmp72_;
	_tmp73_ = (GtkImage*) gtk_image_new_from_icon_name ("network-workgroup", 0);
	_tmp74_ = g_object_ref_sink (_tmp73_);
	_g_object_unref0 (self->priv->url_image);
	self->priv->url_image = _tmp74_;
	_tmp75_ = self->priv->url_image;
	gtk_image_set_pixel_size (_tmp75_, 96);
	_tmp76_ = hbox;
	_tmp77_ = self->priv->url_image;
	gtk_box_pack_start (_tmp76_, (GtkWidget*) _tmp77_, FALSE, FALSE, (guint) 0);
	_tmp78_ = (GtkLabel*) gtk_label_new (NULL);
	_tmp79_ = g_object_ref_sink (_tmp78_);
	_g_object_unref0 (self->priv->url_label);
	self->priv->url_label = _tmp79_;
	_tmp80_ = self->priv->url_label;
	g_object_set ((GtkMisc*) _tmp80_, "xalign", 0.0f, NULL);
	_tmp81_ = self->priv->url_label;
	_tmp82_ = _ ("<b>Desktop Access</b>\n" \
"\n" \
"Will add boxes for all systems available from this account.");
	gtk_label_set_markup (_tmp81_, _tmp82_);
	_tmp83_ = self->priv->url_label;
	gtk_label_set_use_markup (_tmp83_, TRUE);
	_tmp84_ = self->priv->url_label;
	g_object_set (_tmp84_, "wrap", TRUE, NULL);
	_tmp85_ = hbox;
	_tmp86_ = self->priv->url_label;
	gtk_box_pack_start (_tmp85_, (GtkWidget*) _tmp86_, TRUE, TRUE, (guint) 0);
	_tmp87_ = hbox;
	gtk_container_add ((GtkContainer*) vbox, (GtkWidget*) _tmp87_);
	_tmp88_ = self->priv->notebook;
	gtk_widget_show_all ((GtkWidget*) _tmp88_);
	boxes_wizard_source_add_media_entries (self, NULL, NULL);
	_g_object_unref0 (vbox);
	_g_object_unref0 (prev);
	_g_object_unref0 (url_menubox);
	_g_object_unref0 (next);
	_g_object_unref0 (label);
	_g_object_unref0 (hbox);
	return self;
}


BoxesWizardSource* boxes_wizard_source_new (BoxesApp* app, BoxesMediaManager* media_manager) {
	return boxes_wizard_source_construct (BOXES_TYPE_WIZARD_SOURCE, app, media_manager);
}


void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name) {
	GtkLabel* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkImage* _tmp9_;
	const gchar* _tmp10_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (title != NULL);
	g_return_if_fail (text != NULL);
	g_return_if_fail (icon_name != NULL);
	_tmp0_ = self->priv->url_label;
	_tmp1_ = title;
	_tmp2_ = g_strconcat ("<b>", _tmp1_, NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strconcat (_tmp3_, "</b>\n\n", NULL);
	_tmp5_ = _tmp4_;
	_tmp6_ = text;
	_tmp7_ = g_strconcat (_tmp5_, _tmp6_, NULL);
	_tmp8_ = _tmp7_;
	gtk_label_set_markup (_tmp0_, _tmp8_);
	_g_free0 (_tmp8_);
	_g_free0 (_tmp5_);
	_g_free0 (_tmp3_);
	_tmp9_ = self->priv->url_image;
	_tmp10_ = icon_name;
	g_object_set (_tmp9_, "icon-name", _tmp10_, NULL);
}


static void boxes_wizard_source_add_media_entries_data_free (gpointer _data) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (BoxesWizardSourceAddMediaEntriesData, _data_);
}


static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	BoxesWizardSource* _tmp0_;
	_data_ = g_slice_new0 (BoxesWizardSourceAddMediaEntriesData);
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_source_add_media_entries);
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_source_add_media_entries_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	boxes_wizard_source_add_media_entries_co (_data_);
}


static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
}


static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	boxes_wizard_source_add_media_entries_co (_data_);
}


static void _g_object_unref0_ (gpointer var) {
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}


static void _g_list_free__g_object_unref0_ (GList* self) {
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
	g_list_free (self);
}


static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->media_manager;
	_data_->_state_ = 1;
	boxes_media_manager_list_installer_medias (_data_->_tmp0_, boxes_wizard_source_add_media_entries_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp1_ = NULL;
	_data_->_tmp1_ = boxes_media_manager_list_installer_medias_finish (_data_->_tmp0_, _data_->_res_);
	_data_->medias = _data_->_tmp1_;
	_data_->_tmp2_ = _data_->self->priv->media_vbox;
	_data_->_tmp3_ = NULL;
	_data_->_tmp3_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp2_);
	{
		_data_->child_collection = _data_->_tmp3_;
		for (_data_->child_it = _data_->child_collection; _data_->child_it != NULL; _data_->child_it = _data_->child_it->next) {
			_data_->child = (GtkWidget*) _data_->child_it->data;
			{
				_data_->_tmp4_ = _data_->child;
				_data_->_tmp5_ = NULL;
				_data_->_tmp5_ = g_object_get_data ((GObject*) _data_->_tmp4_, "boxes-media");
				_data_->_tmp6_ = g_strdup ((const gchar*) _data_->_tmp5_);
				_data_->child_media = _data_->_tmp6_;
				_data_->_tmp7_ = _data_->child_media;
				if (_data_->_tmp7_ == NULL) {
					_g_free0 (_data_->child_media);
					continue;
				}
				_data_->obsolete = TRUE;
				_data_->_tmp8_ = _data_->medias;
				{
					_data_->media_collection = _data_->_tmp8_;
					for (_data_->media_it = _data_->media_collection; _data_->media_it != NULL; _data_->media_it = _data_->media_it->next) {
						_data_->_tmp9_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->media_it->data);
						_data_->media = _data_->_tmp9_;
						{
							_data_->_tmp10_ = _data_->child_media;
							_data_->_tmp11_ = _data_->media;
							_data_->_tmp12_ = _data_->_tmp11_->device_file;
							if (g_strcmp0 (_data_->_tmp10_, _data_->_tmp12_) == 0) {
								_data_->obsolete = FALSE;
								_g_object_unref0 (_data_->media);
								break;
							}
							_g_object_unref0 (_data_->media);
						}
					}
				}
				_data_->_tmp13_ = _data_->obsolete;
				if (_data_->_tmp13_) {
					_data_->_tmp14_ = _data_->self->priv->main_vbox;
					_data_->_tmp15_ = _data_->child;
					gtk_container_remove ((GtkContainer*) _data_->_tmp14_, _data_->_tmp15_);
				}
				_g_free0 (_data_->child_media);
			}
		}
		_g_list_free0 (_data_->child_collection);
	}
	_data_->_tmp16_ = _data_->medias;
	{
		_data_->_vala1_media_collection = _data_->_tmp16_;
		for (_data_->_vala1_media_it = _data_->_vala1_media_collection; _data_->_vala1_media_it != NULL; _data_->_vala1_media_it = _data_->_vala1_media_it->next) {
			_data_->_tmp17_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->_vala1_media_it->data);
			_data_->_vala1_media = _data_->_tmp17_;
			{
				_data_->nouveau = TRUE;
				_data_->_tmp18_ = _data_->self->priv->media_vbox;
				_data_->_tmp19_ = NULL;
				_data_->_tmp19_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp18_);
				{
					_data_->_vala1_child_collection = _data_->_tmp19_;
					for (_data_->_vala1_child_it = _data_->_vala1_child_collection; _data_->_vala1_child_it != NULL; _data_->_vala1_child_it = _data_->_vala1_child_it->next) {
						_data_->_vala1_child = (GtkWidget*) _data_->_vala1_child_it->data;
						{
							_data_->_tmp20_ = _data_->_vala1_child;
							_data_->_tmp21_ = NULL;
							_data_->_tmp21_ = g_object_get_data ((GObject*) _data_->_tmp20_, "boxes-media");
							_data_->_tmp22_ = g_strdup ((const gchar*) _data_->_tmp21_);
							_data_->_vala1_child_media = _data_->_tmp22_;
							_data_->_tmp24_ = _data_->_vala1_child_media;
							if (_data_->_tmp24_ != NULL) {
								_data_->_tmp25_ = _data_->_vala1_child_media;
								_data_->_tmp26_ = _data_->_vala1_media;
								_data_->_tmp27_ = _data_->_tmp26_->device_file;
								_data_->_tmp23_ = g_strcmp0 (_data_->_tmp25_, _data_->_tmp27_) == 0;
							} else {
								_data_->_tmp23_ = FALSE;
							}
							_data_->_tmp28_ = _data_->_tmp23_;
							if (_data_->_tmp28_) {
								_data_->nouveau = FALSE;
								_g_free0 (_data_->_vala1_child_media);
								break;
							}
							_g_free0 (_data_->_vala1_child_media);
						}
					}
					_g_list_free0 (_data_->_vala1_child_collection);
				}
				_data_->_tmp29_ = _data_->nouveau;
				if (_data_->_tmp29_) {
					_data_->_tmp30_ = _data_->_vala1_media;
					boxes_wizard_source_add_media_entry (_data_->self, _data_->_tmp30_);
				}
				_g_object_unref0 (_data_->_vala1_media);
			}
		}
	}
	_data_->_tmp31_ = _data_->self->priv->media_vbox;
	_data_->_tmp32_ = NULL;
	_data_->_tmp32_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp31_);
	_data_->_tmp33_ = _data_->_tmp32_;
	_data_->_tmp34_ = 0U;
	_data_->_tmp34_ = g_list_length (_data_->_tmp33_);
	_data_->_tmp35_ = _data_->_tmp34_ == ((guint) 0);
	_g_list_free0 (_data_->_tmp33_);
	if (_data_->_tmp35_) {
		_data_->_tmp36_ = _data_->self->priv->media_scrolled;
		gtk_widget_hide ((GtkWidget*) _data_->_tmp36_);
	}
	__g_list_free__g_object_unref0_0 (_data_->medias);
	if (_data_->_state_ == 0) {
		g_simple_async_result_complete_in_idle (_data_->_async_result);
	} else {
		g_simple_async_result_complete (_data_->_async_result);
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static Block35Data* block35_data_ref (Block35Data* _data35_) {
	g_atomic_int_inc (&_data35_->_ref_count_);
	return _data35_;
}


static void block35_data_unref (void * _userdata_) {
	Block35Data* _data35_;
	_data35_ = (Block35Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data35_->_ref_count_)) {
		BoxesWizardSource * self;
		self = _data35_->self;
		_g_object_unref0 (_data35_->media);
		_g_object_unref0 (self);
		g_slice_free (Block35Data, _data35_);
	}
}


static void __lambda52_ (Block35Data* _data35_) {
	BoxesWizardSource * self;
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	const gchar* _tmp2_;
	GtkEntry* _tmp3_;
	self = _data35_->self;
	_tmp0_ = _data35_->media;
	boxes_wizard_source_set_install_media (self, _tmp0_);
	_tmp1_ = _data35_->media;
	_tmp2_ = _tmp1_->device_file;
	boxes_wizard_source_set_uri (self, _tmp2_);
	_tmp3_ = self->url_entry;
	g_signal_emit_by_name (_tmp3_, "activate");
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
}


static void ___lambda52__clicked_func (gpointer self) {
	__lambda52_ (self);
}


static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	Block35Data* _data35_;
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	GtkBox* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	const gchar* _tmp4_;
	GtkBox* _tmp5_ = NULL;
	GtkBox* hbox;
	BoxesInstallerMedia* _tmp6_;
	OsinfoOs* _tmp7_;
	GtkImage* _tmp8_ = NULL;
	GtkImage* image;
	GtkBox* _tmp9_;
	GtkImage* _tmp10_;
	GtkVBox* _tmp11_;
	GtkVBox* _tmp12_;
	GtkVBox* vbox;
	GtkBox* _tmp13_;
	GtkVBox* _tmp14_;
	BoxesInstallerMedia* _tmp15_;
	const gchar* _tmp16_;
	GtkLabel* _tmp17_;
	GtkLabel* _tmp18_;
	GtkLabel* label;
	GtkLabel* _tmp19_;
	GtkLabel* _tmp20_;
	GtkStyleContext* _tmp21_ = NULL;
	GtkLabel* _tmp22_;
	GtkVBox* _tmp23_;
	GtkLabel* _tmp24_;
	BoxesInstallerMedia* _tmp25_;
	OsinfoMedia* _tmp26_;
	GtkBox* _tmp71_;
	GtkScrolledWindow* _tmp72_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (media != NULL);
	_data35_ = g_slice_new0 (Block35Data);
	_data35_->_ref_count_ = 1;
	_data35_->self = g_object_ref (self);
	_tmp0_ = media;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_data35_->media = _tmp1_;
	_tmp2_ = self->priv->media_vbox;
	_tmp3_ = _data35_->media;
	_tmp4_ = _tmp3_->device_file;
	_tmp5_ = boxes_wizard_source_add_entry (self, _tmp2_, ___lambda52__clicked_func, block35_data_ref (_data35_), block35_data_unref, 15, 5, _tmp4_);
	hbox = _tmp5_;
	_tmp6_ = _data35_->media;
	_tmp7_ = _tmp6_->os;
	_tmp8_ = boxes_get_os_logo (_tmp7_, 64);
	image = _tmp8_;
	_tmp9_ = hbox;
	_tmp10_ = image;
	gtk_box_pack_start (_tmp9_, (GtkWidget*) _tmp10_, FALSE, FALSE, (guint) 0);
	_tmp11_ = (GtkVBox*) gtk_vbox_new (TRUE, 5);
	_tmp12_ = g_object_ref_sink (_tmp11_);
	vbox = _tmp12_;
	_tmp13_ = hbox;
	_tmp14_ = vbox;
	gtk_box_pack_start (_tmp13_, (GtkWidget*) _tmp14_, TRUE, TRUE, (guint) 0);
	_tmp15_ = _data35_->media;
	_tmp16_ = _tmp15_->label;
	_tmp17_ = (GtkLabel*) gtk_label_new (_tmp16_);
	_tmp18_ = g_object_ref_sink (_tmp17_);
	label = _tmp18_;
	_tmp19_ = label;
	gtk_label_set_ellipsize (_tmp19_, PANGO_ELLIPSIZE_END);
	_tmp20_ = label;
	_tmp21_ = gtk_widget_get_style_context ((GtkWidget*) _tmp20_);
	gtk_style_context_add_class (_tmp21_, "boxes-source-label");
	_tmp22_ = label;
	g_object_set ((GtkMisc*) _tmp22_, "xalign", 0.0f, NULL);
	_tmp23_ = vbox;
	_tmp24_ = label;
	gtk_box_pack_start ((GtkBox*) _tmp23_, (GtkWidget*) _tmp24_, TRUE, TRUE, (guint) 0);
	_tmp25_ = _data35_->media;
	_tmp26_ = _tmp25_->os_media;
	if (_tmp26_ != NULL) {
		const gchar* _tmp27_ = NULL;
		gboolean _tmp28_ = FALSE;
		BoxesInstallerMedia* _tmp29_;
		OsinfoMedia* _tmp30_;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gboolean _tmp34_;
		gboolean _tmp40_;
		const gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* architecture;
		const gchar* _tmp45_;
		GtkLabel* _tmp46_;
		GtkLabel* _tmp47_;
		GtkLabel* _tmp48_;
		GtkLabel* _tmp49_;
		GtkStyleContext* _tmp50_ = NULL;
		GtkLabel* _tmp51_;
		GtkVBox* _tmp52_;
		GtkLabel* _tmp53_;
		BoxesInstallerMedia* _tmp54_;
		OsinfoOs* _tmp55_;
		const gchar* _tmp56_;
		const gchar* _tmp57_;
		_tmp29_ = _data35_->media;
		_tmp30_ = _tmp29_->os_media;
		g_object_get (_tmp30_, "architecture", &_tmp31_, NULL);
		_tmp32_ = _tmp31_;
		_tmp33_ = _tmp32_;
		_tmp34_ = g_strcmp0 (_tmp33_, "i386") == 0;
		_g_free0 (_tmp33_);
		if (_tmp34_) {
			_tmp28_ = TRUE;
		} else {
			BoxesInstallerMedia* _tmp35_;
			OsinfoMedia* _tmp36_;
			gchar* _tmp37_ = NULL;
			gchar* _tmp38_;
			gchar* _tmp39_;
			_tmp35_ = _data35_->media;
			_tmp36_ = _tmp35_->os_media;
			g_object_get (_tmp36_, "architecture", &_tmp37_, NULL);
			_tmp38_ = _tmp37_;
			_tmp39_ = _tmp38_;
			_tmp28_ = g_strcmp0 (_tmp39_, "i686") == 0;
			_g_free0 (_tmp39_);
		}
		_tmp40_ = _tmp28_;
		if (_tmp40_) {
			const gchar* _tmp41_ = NULL;
			_tmp41_ = _ ("32-bit x86 system");
			_tmp27_ = _tmp41_;
		} else {
			const gchar* _tmp42_ = NULL;
			_tmp42_ = _ ("64-bit x86 system");
			_tmp27_ = _tmp42_;
		}
		_tmp43_ = _tmp27_;
		_tmp44_ = g_strdup (_tmp43_);
		architecture = _tmp44_;
		_tmp45_ = architecture;
		_tmp46_ = (GtkLabel*) gtk_label_new (_tmp45_);
		_tmp47_ = g_object_ref_sink (_tmp46_);
		_g_object_unref0 (label);
		label = _tmp47_;
		_tmp48_ = label;
		gtk_label_set_ellipsize (_tmp48_, PANGO_ELLIPSIZE_END);
		_tmp49_ = label;
		_tmp50_ = gtk_widget_get_style_context ((GtkWidget*) _tmp49_);
		gtk_style_context_add_class (_tmp50_, "boxes-step-label");
		_tmp51_ = label;
		g_object_set ((GtkMisc*) _tmp51_, "xalign", 0.0f, NULL);
		_tmp52_ = vbox;
		_tmp53_ = label;
		gtk_box_pack_start ((GtkBox*) _tmp52_, (GtkWidget*) _tmp53_, TRUE, TRUE, (guint) 0);
		_tmp54_ = _data35_->media;
		_tmp55_ = _tmp54_->os;
		_tmp56_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp55_);
		_tmp57_ = _tmp56_;
		if (_tmp57_ != NULL) {
			GtkLabel* _tmp58_;
			GtkLabel* _tmp59_;
			const gchar* _tmp60_;
			const gchar* _tmp61_;
			const gchar* _tmp62_ = NULL;
			BoxesInstallerMedia* _tmp63_;
			OsinfoOs* _tmp64_;
			const gchar* _tmp65_;
			const gchar* _tmp66_;
			gchar* _tmp67_ = NULL;
			gchar* _tmp68_;
			gchar* _tmp69_;
			gchar* _tmp70_;
			_tmp58_ = label;
			_tmp59_ = label;
			_tmp60_ = gtk_label_get_label (_tmp59_);
			_tmp61_ = _tmp60_;
			_tmp62_ = _ (" from %s");
			_tmp63_ = _data35_->media;
			_tmp64_ = _tmp63_->os;
			_tmp65_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp64_);
			_tmp66_ = _tmp65_;
			_tmp67_ = g_strdup_printf (_tmp62_, _tmp66_);
			_tmp68_ = _tmp67_;
			_tmp69_ = g_strconcat (_tmp61_, _tmp68_, NULL);
			_tmp70_ = _tmp69_;
			gtk_label_set_label (_tmp59_, _tmp70_);
			_g_free0 (_tmp70_);
			_g_free0 (_tmp68_);
		}
		_g_free0 (architecture);
	}
	_tmp71_ = self->priv->media_vbox;
	gtk_widget_show_all ((GtkWidget*) _tmp71_);
	_tmp72_ = self->priv->media_scrolled;
	gtk_widget_show ((GtkWidget*) _tmp72_);
	_g_object_unref0 (label);
	_g_object_unref0 (vbox);
	_g_object_unref0 (image);
	_g_object_unref0 (hbox);
	block35_data_unref (_data35_);
	_data35_ = NULL;
}


static Block36Data* block36_data_ref (Block36Data* _data36_) {
	g_atomic_int_inc (&_data36_->_ref_count_);
	return _data36_;
}


static void block36_data_unref (void * _userdata_) {
	Block36Data* _data36_;
	_data36_ = (Block36Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data36_->_ref_count_)) {
		BoxesWizardSource * self;
		self = _data36_->self;
		(_data36_->clicked_target_destroy_notify == NULL) ? NULL : (_data36_->clicked_target_destroy_notify (_data36_->clicked_target), NULL);
		_data36_->clicked = NULL;
		_data36_->clicked_target = NULL;
		_data36_->clicked_target_destroy_notify = NULL;
		_g_object_unref0 (self);
		g_slice_free (Block36Data, _data36_);
	}
}


static void ___lambda49_ (Block36Data* _data36_) {
	BoxesWizardSource * self;
	ClickedFunc _tmp0_;
	void* _tmp0__target;
	self = _data36_->self;
	_tmp0_ = _data36_->clicked;
	_tmp0__target = _data36_->clicked_target;
	_tmp0_ (_tmp0__target);
}


static void ____lambda49__gtk_button_clicked (GtkButton* _sender, gpointer self) {
	___lambda49_ (self);
}


static Block37Data* block37_data_ref (Block37Data* _data37_) {
	g_atomic_int_inc (&_data37_->_ref_count_);
	return _data37_;
}


static void block37_data_unref (void * _userdata_) {
	Block37Data* _data37_;
	_data37_ = (Block37Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data37_->_ref_count_)) {
		BoxesWizardSource * self;
		self = _data37_->_data36_->self;
		_g_object_unref0 (_data37_->bin);
		block36_data_unref (_data37_->_data36_);
		_data37_->_data36_ = NULL;
		g_slice_free (Block37Data, _data37_);
	}
}


static gboolean ___lambda50_ (Block37Data* _data37_, cairo_t* cr) {
	Block36Data* _data36_;
	BoxesWizardSource * self;
	gboolean result = FALSE;
	GtkAlignment* _tmp0_;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_;
	GtkStyleContext* context;
	GtkAllocation allocation = {0};
	GtkAlignment* _tmp3_;
	GtkAllocation _tmp4_ = {0};
	cairo_t* _tmp5_;
	GtkAllocation _tmp6_;
	gint _tmp7_;
	GtkAllocation _tmp8_;
	gint _tmp9_;
	cairo_t* _tmp10_;
	GtkAllocation _tmp11_;
	gint _tmp12_;
	GtkAllocation _tmp13_;
	gint _tmp14_;
	_data36_ = _data37_->_data36_;
	self = _data36_->self;
	g_return_val_if_fail (cr != NULL, FALSE);
	_tmp0_ = _data37_->bin;
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) _tmp0_);
	_tmp2_ = _g_object_ref0 (_tmp1_);
	context = _tmp2_;
	_tmp3_ = _data37_->bin;
	gtk_widget_get_allocation ((GtkWidget*) _tmp3_, &_tmp4_);
	allocation = _tmp4_;
	_tmp5_ = cr;
	_tmp6_ = allocation;
	_tmp7_ = _tmp6_.width;
	_tmp8_ = allocation;
	_tmp9_ = _tmp8_.height;
	gtk_render_background (context, _tmp5_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp7_, (gdouble) _tmp9_);
	_tmp10_ = cr;
	_tmp11_ = allocation;
	_tmp12_ = _tmp11_.width;
	_tmp13_ = allocation;
	_tmp14_ = _tmp13_.height;
	gtk_render_frame (context, _tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp12_, (gdouble) _tmp14_);
	result = FALSE;
	_g_object_unref0 (context);
	return result;
}


static gboolean ____lambda50__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = ___lambda50_ (self, cr);
	return result;
}


static GtkBox* boxes_wizard_source_add_entry (BoxesWizardSource* self, GtkBox* box, ClickedFunc clicked, void* clicked_target, GDestroyNotify clicked_target_destroy_notify, gint h_margin, gint v_margin, const gchar* media) {
	GtkBox* result = NULL;
	Block36Data* _data36_;
	ClickedFunc _tmp0_;
	void* _tmp0__target;
	GtkContainer* row = NULL;
	ClickedFunc _tmp1_;
	void* _tmp1__target;
	GtkBox* _tmp12_;
	GtkBox* _tmp13_;
	GtkBox* hbox;
	GtkContainer* _tmp14_;
	GtkBox* _tmp15_;
	GtkContainer* _tmp16_;
	GtkStyleContext* _tmp17_ = NULL;
	GtkBox* _tmp18_;
	GtkContainer* _tmp19_;
	const gchar* _tmp20_;
	GtkBox* _tmp24_;
	GtkBox* _tmp25_;
	gint _tmp26_;
	GtkBox* _tmp27_;
	GtkBox* _tmp28_;
	gint _tmp29_;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (box != NULL, NULL);
	_data36_ = g_slice_new0 (Block36Data);
	_data36_->_ref_count_ = 1;
	_data36_->self = g_object_ref (self);
	_tmp0_ = clicked;
	_tmp0__target = clicked_target;
	(_data36_->clicked_target_destroy_notify == NULL) ? NULL : (_data36_->clicked_target_destroy_notify (_data36_->clicked_target), NULL);
	_data36_->clicked = NULL;
	_data36_->clicked_target = NULL;
	_data36_->clicked_target_destroy_notify = NULL;
	_data36_->clicked = _tmp0_;
	_data36_->clicked_target = _tmp0__target;
	_data36_->clicked_target_destroy_notify = clicked_target_destroy_notify;
	_tmp1_ = _data36_->clicked;
	_tmp1__target = _data36_->clicked_target;
	if (_tmp1_ != NULL) {
		GtkButton* _tmp2_;
		GtkButton* _tmp3_;
		GtkButton* button;
		GtkButton* _tmp4_;
		GtkButton* _tmp5_;
		GtkContainer* _tmp6_;
		_tmp2_ = (GtkButton*) gtk_button_new ();
		_tmp3_ = g_object_ref_sink (_tmp2_);
		button = _tmp3_;
		_tmp4_ = button;
		g_signal_connect_data (_tmp4_, "clicked", (GCallback) ____lambda49__gtk_button_clicked, block36_data_ref (_data36_), (GClosureNotify) block36_data_unref, 0);
		_tmp5_ = button;
		_tmp6_ = _g_object_ref0 ((GtkContainer*) _tmp5_);
		_g_object_unref0 (row);
		row = _tmp6_;
		_g_object_unref0 (button);
	} else {
		Block37Data* _data37_;
		GtkAlignment* _tmp7_;
		GtkAlignment* _tmp8_;
		GtkAlignment* _tmp9_;
		GtkAlignment* _tmp10_;
		GtkContainer* _tmp11_;
		_data37_ = g_slice_new0 (Block37Data);
		_data37_->_ref_count_ = 1;
		_data37_->_data36_ = block36_data_ref (_data36_);
		_tmp7_ = (GtkAlignment*) gtk_alignment_new ((gfloat) 0, (gfloat) 0, (gfloat) 1, (gfloat) 1);
		_tmp8_ = g_object_ref_sink (_tmp7_);
		_data37_->bin = _tmp8_;
		_tmp9_ = _data37_->bin;
		g_signal_connect_data ((GtkWidget*) _tmp9_, "draw", (GCallback) ____lambda50__gtk_widget_draw, block37_data_ref (_data37_), (GClosureNotify) block37_data_unref, 0);
		_tmp10_ = _data37_->bin;
		_tmp11_ = _g_object_ref0 ((GtkContainer*) _tmp10_);
		_g_object_unref0 (row);
		row = _tmp11_;
		block37_data_unref (_data37_);
		_data37_ = NULL;
	}
	_tmp12_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 20);
	_tmp13_ = g_object_ref_sink (_tmp12_);
	hbox = _tmp13_;
	_tmp14_ = row;
	_tmp15_ = hbox;
	gtk_container_add (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = row;
	_tmp17_ = gtk_widget_get_style_context ((GtkWidget*) _tmp16_);
	gtk_style_context_add_class (_tmp17_, "boxes-menu-row");
	_tmp18_ = box;
	_tmp19_ = row;
	gtk_container_add ((GtkContainer*) _tmp18_, (GtkWidget*) _tmp19_);
	_tmp20_ = media;
	if (_tmp20_ != NULL) {
		GtkContainer* _tmp21_;
		const gchar* _tmp22_;
		gchar* _tmp23_;
		_tmp21_ = row;
		_tmp22_ = media;
		_tmp23_ = g_strdup (_tmp22_);
		g_object_set_data_full ((GObject*) _tmp21_, "boxes-media", _tmp23_, g_free);
	}
	_tmp24_ = hbox;
	_tmp25_ = hbox;
	_tmp26_ = h_margin;
	gtk_widget_set_margin_right ((GtkWidget*) _tmp25_, _tmp26_);
	gtk_widget_set_margin_left ((GtkWidget*) _tmp24_, _tmp26_);
	_tmp27_ = hbox;
	_tmp28_ = hbox;
	_tmp29_ = v_margin;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp28_, _tmp29_);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp27_, _tmp29_);
	result = hbox;
	_g_object_unref0 (row);
	block36_data_unref (_data36_);
	_data36_ = NULL;
	return result;
}


static void boxes_wizard_source_launch_file_selection_dialog (BoxesWizardSource* self) {
	const gchar* _tmp0_ = NULL;
	BoxesApp* _tmp1_;
	GtkApplicationWindow* _tmp2_;
	GtkFileChooserDialog* _tmp3_;
	GtkFileChooserDialog* _tmp4_;
	GtkFileChooserDialog* dialog;
	GtkFileChooserDialog* _tmp5_;
	GtkFileChooserDialog* _tmp6_;
	GtkFileChooserDialog* _tmp7_;
	GtkFileFilter* _tmp8_;
	GtkFileFilter* _tmp9_;
	GtkFileChooserDialog* _tmp10_;
	GtkFileFilter* _tmp11_;
	GtkFileFilter* _tmp12_;
	GtkFileChooserDialog* _tmp13_;
	gint _tmp14_ = 0;
	GtkFileChooserDialog* _tmp19_;
	g_return_if_fail (self != NULL);
	_tmp0_ = _ ("Select a device or ISO file");
	_tmp1_ = self->priv->app;
	_tmp2_ = _tmp1_->window;
	_tmp3_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp0_, (GtkWindow*) _tmp2_, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
	_tmp4_ = g_object_ref_sink (_tmp3_);
	dialog = _tmp4_;
	_tmp5_ = dialog;
	gtk_file_chooser_set_show_hidden ((GtkFileChooser*) _tmp5_, FALSE);
	_tmp6_ = dialog;
	gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp6_, TRUE);
	_tmp7_ = dialog;
	_tmp8_ = gtk_file_filter_new ();
	_tmp9_ = g_object_ref_sink (_tmp8_);
	gtk_file_chooser_set_filter ((GtkFileChooser*) _tmp7_, _tmp9_);
	_g_object_unref0 (_tmp9_);
	_tmp10_ = dialog;
	_tmp11_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp10_);
	_tmp12_ = _tmp11_;
	gtk_file_filter_add_mime_type (_tmp12_, "application/x-cd-image");
	_tmp13_ = dialog;
	_tmp14_ = gtk_dialog_run ((GtkDialog*) _tmp13_);
	if (_tmp14_ == ((gint) GTK_RESPONSE_ACCEPT)) {
		GtkFileChooserDialog* _tmp15_;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_;
		GtkEntry* _tmp18_;
		_tmp15_ = dialog;
		_tmp16_ = gtk_file_chooser_get_uri ((GtkFileChooser*) _tmp15_);
		_tmp17_ = _tmp16_;
		boxes_wizard_source_set_uri (self, _tmp17_);
		_g_free0 (_tmp17_);
		_tmp18_ = self->url_entry;
		g_signal_emit_by_name (_tmp18_, "activate");
		boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
	}
	_tmp19_ = dialog;
	gtk_widget_hide ((GtkWidget*) _tmp19_);
	_g_object_unref0 (dialog);
}


GtkWidget* boxes_wizard_source_get_widget (BoxesWizardSource* self) {
	GtkWidget* result;
	GtkNotebook* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->notebook;
	result = (GtkWidget*) _tmp0_;
	return result;
}


BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self) {
	BoxesSourcePage result;
	BoxesSourcePage _tmp0_;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = self->priv->_page;
	result = _tmp0_;
	return result;
}


void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value) {
	BoxesSourcePage _tmp0_;
	GtkNotebook* _tmp1_;
	BoxesSourcePage _tmp2_;
	BoxesSourcePage _tmp3_;
	BoxesSourcePage _tmp4_;
	BoxesSourcePage _tmp5_;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_page = _tmp0_;
	_tmp1_ = self->priv->notebook;
	_tmp2_ = boxes_wizard_source_get_page (self);
	_tmp3_ = _tmp2_;
	gtk_notebook_set_current_page (_tmp1_, (gint) _tmp3_);
	_tmp4_ = boxes_wizard_source_get_page (self);
	_tmp5_ = _tmp4_;
	switch (_tmp5_) {
		case BOXES_SOURCE_PAGE_MAIN:
		{
			GtkBox* _tmp6_;
			boxes_wizard_source_add_media_entries (self, NULL, NULL);
			_tmp6_ = self->priv->main_vbox;
			gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
			break;
		}
		case BOXES_SOURCE_PAGE_URL:
		{
			GtkEntry* _tmp7_;
			GtkEntry* _tmp8_;
			_tmp7_ = self->url_entry;
			g_signal_emit_by_name ((GtkEditable*) _tmp7_, "changed");
			_tmp8_ = self->url_entry;
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
			break;
		}
		default:
		break;
	}
	g_object_notify ((GObject *) self, "page");
}


const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self) {
	const gchar* result;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->url_entry;
	_tmp1_ = gtk_entry_get_text (_tmp0_);
	result = _tmp1_;
	return result;
}


void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value) {
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->url_entry;
	_tmp1_ = value;
	gtk_entry_set_text (_tmp0_, _tmp1_);
	g_object_notify ((GObject *) self, "uri");
}


BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_install_media;
	result = _tmp0_;
	return result;
}


static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->priv->_install_media);
	self->priv->_install_media = _tmp1_;
	g_object_notify ((GObject *) self, "install-media");
}


static void boxes_wizard_source_class_init (BoxesWizardSourceClass * klass) {
	boxes_wizard_source_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (BoxesWizardSourcePrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_source_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_source_set_property;
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_source_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_SOURCE_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_INSTALL_MEDIA, g_param_spec_object ("install-media", "install-media", "install-media", BOXES_TYPE_INSTALLER_MEDIA, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void boxes_wizard_source_instance_init (BoxesWizardSource * self) {
	self->priv = BOXES_WIZARD_SOURCE_GET_PRIVATE (self);
}


static void boxes_wizard_source_finalize (GObject* obj) {
	BoxesWizardSource * self;
	self = BOXES_WIZARD_SOURCE (obj);
	_g_object_unref0 (self->priv->_install_media);
	_g_object_unref0 (self->priv->main_vbox);
	_g_object_unref0 (self->priv->media_vbox);
	_g_object_unref0 (self->priv->media_scrolled);
	_g_object_unref0 (self->priv->notebook);
	_g_object_unref0 (self->priv->url_label);
	_g_object_unref0 (self->priv->url_image);
	_g_object_unref0 (self->url_entry);
	_g_object_unref0 (self->priv->media_manager);
	_g_object_unref0 (self->priv->app);
	G_OBJECT_CLASS (boxes_wizard_source_parent_class)->finalize (obj);
}


GType boxes_wizard_source_get_type (void) {
	static volatile gsize boxes_wizard_source_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSource), 0, (GInstanceInitFunc) boxes_wizard_source_instance_init, NULL };
		GType boxes_wizard_source_type_id;
		boxes_wizard_source_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesWizardSource", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_source_type_id__volatile, boxes_wizard_source_type_id);
	}
	return boxes_wizard_source_type_id__volatile;
}


static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = BOXES_WIZARD_SOURCE (object);
	switch (property_id) {
		case BOXES_WIZARD_SOURCE_WIDGET:
		g_value_set_object (value, boxes_wizard_source_get_widget (self));
		break;
		case BOXES_WIZARD_SOURCE_PAGE:
		g_value_set_enum (value, boxes_wizard_source_get_page (self));
		break;
		case BOXES_WIZARD_SOURCE_URI:
		g_value_set_string (value, boxes_wizard_source_get_uri (self));
		break;
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
		g_value_set_object (value, boxes_wizard_source_get_install_media (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = BOXES_WIZARD_SOURCE (object);
	switch (property_id) {
		case BOXES_WIZARD_SOURCE_PAGE:
		boxes_wizard_source_set_page (self, g_value_get_enum (value));
		break;
		case BOXES_WIZARD_SOURCE_URI:
		boxes_wizard_source_set_uri (self, g_value_get_string (value));
		break;
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
		boxes_wizard_source_set_install_media (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



